class_name MimeTypeHelper

# order of the enum matters, it's used for ordering preferred extensions
enum SOURCE{
	NGINX,
	APACHE,
	UNKNOWN,
	IANA
}

const UTF8 := "UTF-8"

class MimeType:
	
	var full_type := "application/octet-stream"
	var type := "application"
	var sub_type := "octet-stream"
	var source: int = SOURCE.UNKNOWN
	var charset: = ""
	var extensions := PoolStringArray()
	var compressible := false


	func setup(given_type: String, props := {}) -> void:
		full_type = given_type
		var type_array := full_type.split("/", false, 1)
		type = type_array[0]
		sub_type = type_array[1]
		if 'source' in props:
			source = props.source
		if 'compressible' in props:
			compressible = props.compressible
		if 'charset' in props:
			charset = props.charset
		elif type == 'text':
			charset = UTF8
		if 'extensions' in props:
			extensions = props.extensions


	func _to_string() -> String:
		return full_type

class MimeTypeDb:

	var _db := {}
	var _types := {}
	var _default_mime_type := MimeType.new()


	func process_raw_db(raw_db: Dictionary) -> void:
		
		for type in raw_db:
			var mime_type := MimeType.new()
			mime_type.setup(type, raw_db[type])

			if not mime_type.extensions or type == _default_mime_type.type:
				continue;
			
			for extension in mime_type.extensions:
				if extension in _types and (_types[extension] as MimeType).source > mime_type.source:
					continue
				_types[extension] = mime_type

		
	func get(ext_or_filename: String) -> MimeType:
		var ext := ("x."+ext_or_filename.trim_prefix(".")).get_extension().to_lower()
		if not (ext in _types):
			return _default_mime_type
		return _types[ext]


	func get_type(ext_or_filename: String) -> String:
		return get(ext_or_filename).full_type


static func generate_db() -> MimeTypeDb:
	var db := MimeTypeDb.new()
	db.process_raw_db(RAW_DB)
	return db


const RAW_DB := {
	"application/1d-interleaved-parityfec": {
		"source": SOURCE.IANA
	},
	"application/3gpdash-qoe-report+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/3gpp-ims+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/3gpphal+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/3gpphalforms+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/a2l": {
		"source": SOURCE.IANA
	},
	"application/ace+cbor": {
		"source": SOURCE.IANA
	},
	"application/ace+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/activemessage": {
		"source": SOURCE.IANA
	},
	"application/activity+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/aif+cbor": {
		"source": SOURCE.IANA
	},
	"application/aif+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-cdni+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-cdnifilter+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-costmap+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-costmapfilter+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-directory+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-endpointcost+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-endpointcostparams+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-endpointprop+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-endpointpropparams+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-error+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-networkmap+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-networkmapfilter+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-propmap+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-propmapparams+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-updatestreamcontrol+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/alto-updatestreamparams+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/aml": {
		"source": SOURCE.IANA
	},
	"application/andrew-inset": {
		"source": SOURCE.IANA,
		"extensions": ["ez"]
	},
	"application/applefile": {
		"source": SOURCE.IANA
	},
	"application/applixware": {
		"source": SOURCE.APACHE,
		"extensions": ["aw"]
	},
	"application/at+jwt": {
		"source": SOURCE.IANA
	},
	"application/atf": {
		"source": SOURCE.IANA
	},
	"application/atfx": {
		"source": SOURCE.IANA
	},
	"application/atom+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["atom"]
	},
	"application/atomcat+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["atomcat"]
	},
	"application/atomdeleted+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["atomdeleted"]
	},
	"application/atomicmail": {
		"source": SOURCE.IANA
	},
	"application/atomsvc+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["atomsvc"]
	},
	"application/atsc-dwd+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["dwd"]
	},
	"application/atsc-dynamic-event-message": {
		"source": SOURCE.IANA
	},
	"application/atsc-held+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["held"]
	},
	"application/atsc-rdt+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/atsc-rsat+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rsat"]
	},
	"application/atxml": {
		"source": SOURCE.IANA
	},
	"application/auth-policy+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/bacnet-xdd+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/batch-smtp": {
		"source": SOURCE.IANA
	},
	"application/bdoc": {
		"compressible": false,
		"extensions": ["bdoc"]
	},
	"application/beep+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/calendar+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/calendar+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xcs"]
	},
	"application/call-completion": {
		"source": SOURCE.IANA
	},
	"application/cals-1840": {
		"source": SOURCE.IANA
	},
	"application/captive+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cbor": {
		"source": SOURCE.IANA
	},
	"application/cbor-seq": {
		"source": SOURCE.IANA
	},
	"application/cccex": {
		"source": SOURCE.IANA
	},
	"application/ccmp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/ccxml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ccxml"]
	},
	"application/cda+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/cdfx+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["cdfx"]
	},
	"application/cdmi-capability": {
		"source": SOURCE.IANA,
		"extensions": ["cdmia"]
	},
	"application/cdmi-container": {
		"source": SOURCE.IANA,
		"extensions": ["cdmic"]
	},
	"application/cdmi-domain": {
		"source": SOURCE.IANA,
		"extensions": ["cdmid"]
	},
	"application/cdmi-object": {
		"source": SOURCE.IANA,
		"extensions": ["cdmio"]
	},
	"application/cdmi-queue": {
		"source": SOURCE.IANA,
		"extensions": ["cdmiq"]
	},
	"application/cdni": {
		"source": SOURCE.IANA
	},
	"application/cea": {
		"source": SOURCE.IANA
	},
	"application/cea-2018+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cellml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cfw": {
		"source": SOURCE.IANA
	},
	"application/city+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/clr": {
		"source": SOURCE.IANA
	},
	"application/clue+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/clue_info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cms": {
		"source": SOURCE.IANA
	},
	"application/cnrp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/coap-group+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/coap-payload": {
		"source": SOURCE.IANA
	},
	"application/commonground": {
		"source": SOURCE.IANA
	},
	"application/conference-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cose": {
		"source": SOURCE.IANA
	},
	"application/cose-key": {
		"source": SOURCE.IANA
	},
	"application/cose-key-set": {
		"source": SOURCE.IANA
	},
	"application/cpl+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["cpl"]
	},
	"application/csrattrs": {
		"source": SOURCE.IANA
	},
	"application/csta+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cstadata+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/csvm+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cu-seeme": {
		"source": SOURCE.APACHE,
		"extensions": ["cu"]
	},
	"application/cwl": {
		"source": SOURCE.IANA,
		"extensions": ["cwl"]
	},
	"application/cwl+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/cwt": {
		"source": SOURCE.IANA
	},
	"application/cybercash": {
		"source": SOURCE.IANA
	},
	"application/dart": {
		"compressible": true
	},
	"application/dash+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mpd"]
	},
	"application/dash-patch+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mpp"]
	},
	"application/dashdelta": {
		"source": SOURCE.IANA
	},
	"application/davmount+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["davmount"]
	},
	"application/dca-rft": {
		"source": SOURCE.IANA
	},
	"application/dcd": {
		"source": SOURCE.IANA
	},
	"application/dec-dx": {
		"source": SOURCE.IANA
	},
	"application/dialog-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/dicom": {
		"source": SOURCE.IANA
	},
	"application/dicom+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/dicom+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/dii": {
		"source": SOURCE.IANA
	},
	"application/dit": {
		"source": SOURCE.IANA
	},
	"application/dns": {
		"source": SOURCE.IANA
	},
	"application/dns+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/dns-message": {
		"source": SOURCE.IANA
	},
	"application/docbook+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["raw_dbk"]
	},
	"application/dots+cbor": {
		"source": SOURCE.IANA
	},
	"application/dskpp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/dssc+der": {
		"source": SOURCE.IANA,
		"extensions": ["dssc"]
	},
	"application/dssc+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xdssc"]
	},
	"application/dvcs": {
		"source": SOURCE.IANA
	},
	"application/ecmascript": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["ecma"]
	},
	"application/edi-consent": {
		"source": SOURCE.IANA
	},
	"application/edi-x12": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/edifact": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/efi": {
		"source": SOURCE.IANA
	},
	"application/elm+json": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/elm+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.cap+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/emergencycalldata.comment+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.control+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.deviceinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.ecall.msd": {
		"source": SOURCE.IANA
	},
	"application/emergencycalldata.providerinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.serviceinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.subscriberinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emergencycalldata.veds+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/emma+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["emma"]
	},
	"application/emotionml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["emotionml"]
	},
	"application/encaprtp": {
		"source": SOURCE.IANA
	},
	"application/epp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/epub+zip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["epub"]
	},
	"application/eshop": {
		"source": SOURCE.IANA
	},
	"application/exi": {
		"source": SOURCE.IANA,
		"extensions": ["exi"]
	},
	"application/expect-ct-report+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/express": {
		"source": SOURCE.IANA,
		"extensions": ["exp"]
	},
	"application/fastinfoset": {
		"source": SOURCE.IANA
	},
	"application/fastsoap": {
		"source": SOURCE.IANA
	},
	"application/fdf": {
		"source": SOURCE.IANA,
		"extensions": ["fdf"]
	},
	"application/fdt+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["fdt"]
	},
	"application/fhir+json": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/fhir+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/fido.trusted-apps+json": {
		"compressible": true
	},
	"application/fits": {
		"source": SOURCE.IANA
	},
	"application/flexfec": {
		"source": SOURCE.IANA
	},
	"application/font-sfnt": {
		"source": SOURCE.IANA
	},
	"application/font-tdpfr": {
		"source": SOURCE.IANA,
		"extensions": ["pfr"]
	},
	"application/font-woff": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/framework-attributes+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/geo+json": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["geojson"]
	},
	"application/geo+json-seq": {
		"source": SOURCE.IANA
	},
	"application/geopackage+sqlite3": {
		"source": SOURCE.IANA
	},
	"application/geoxacml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/gltf-buffer": {
		"source": SOURCE.IANA
	},
	"application/gml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["gml"]
	},
	"application/gpx+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["gpx"]
	},
	"application/gxf": {
		"source": SOURCE.APACHE,
		"extensions": ["gxf"]
	},
	"application/gzip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["gz"]
	},
	"application/h224": {
		"source": SOURCE.IANA
	},
	"application/held+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/hjson": {
		"extensions": ["hjson"]
	},
	"application/hl7v2+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/http": {
		"source": SOURCE.IANA
	},
	"application/hyperstudio": {
		"source": SOURCE.IANA,
		"extensions": ["stk"]
	},
	"application/ibe-key-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/ibe-pkg-reply+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/ibe-pp-data": {
		"source": SOURCE.IANA
	},
	"application/iges": {
		"source": SOURCE.IANA
	},
	"application/im-iscomposing+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/index": {
		"source": SOURCE.IANA
	},
	"application/index.cmd": {
		"source": SOURCE.IANA
	},
	"application/index.obj": {
		"source": SOURCE.IANA
	},
	"application/index.response": {
		"source": SOURCE.IANA
	},
	"application/index.vnd": {
		"source": SOURCE.IANA
	},
	"application/inkml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ink","inkml"]
	},
	"application/iotp": {
		"source": SOURCE.IANA
	},
	"application/ipfix": {
		"source": SOURCE.IANA,
		"extensions": ["ipfix"]
	},
	"application/ipp": {
		"source": SOURCE.IANA
	},
	"application/isup": {
		"source": SOURCE.IANA
	},
	"application/its+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["its"]
	},
	"application/java-archive": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["jar","war","ear"]
	},
	"application/java-serialized-object": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["ser"]
	},
	"application/java-vm": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["class"]
	},
	"application/javascript": {
		"source": SOURCE.APACHE,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["js"]
	},
	"application/jf2feed+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/jose": {
		"source": SOURCE.IANA
	},
	"application/jose+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/jrd+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/jscalendar+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/json": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["json","map"]
	},
	"application/json-patch+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/json-seq": {
		"source": SOURCE.IANA
	},
	"application/json5": {
		"extensions": ["json5"]
	},
	"application/jsonml+json": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["jsonml"]
	},
	"application/jwk+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/jwk-set+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/jwt": {
		"source": SOURCE.IANA
	},
	"application/kpml-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/kpml-response+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/ld+json": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["jsonld"]
	},
	"application/lgr+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["lgr"]
	},
	"application/link-format": {
		"source": SOURCE.IANA
	},
	"application/linkset": {
		"source": SOURCE.IANA
	},
	"application/linkset+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/load-control+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/lost+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["lostxml"]
	},
	"application/lostsync+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/lpf+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/lxf": {
		"source": SOURCE.IANA
	},
	"application/mac-binhex40": {
		"source": SOURCE.IANA,
		"extensions": ["hqx"]
	},
	"application/mac-compactpro": {
		"source": SOURCE.APACHE,
		"extensions": ["cpt"]
	},
	"application/macwriteii": {
		"source": SOURCE.IANA
	},
	"application/mads+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mads"]
	},
	"application/manifest+json": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["webmanifest"]
	},
	"application/marc": {
		"source": SOURCE.IANA,
		"extensions": ["mrc"]
	},
	"application/marcxml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mrcx"]
	},
	"application/mathematica": {
		"source": SOURCE.IANA,
		"extensions": ["ma","nb","mb"]
	},
	"application/mathml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mathml"]
	},
	"application/mathml-content+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mathml-presentation+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-associated-procedure-description+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-deregister+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-envelope+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-msk+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-msk-response+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-protection-description+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-reception-report+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-register+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-register-response+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-schedule+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbms-user-service-description+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mbox": {
		"source": SOURCE.IANA,
		"extensions": ["mbox"]
	},
	"application/media-policy-dataset+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mpf"]
	},
	"application/media_control+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mediaservercontrol+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mscml"]
	},
	"application/merge-patch+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/metalink+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["metalink"]
	},
	"application/metalink4+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["meta4"]
	},
	"application/mets+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mets"]
	},
	"application/mf4": {
		"source": SOURCE.IANA
	},
	"application/mikey": {
		"source": SOURCE.IANA
	},
	"application/mipc": {
		"source": SOURCE.IANA
	},
	"application/missing-blocks+cbor-seq": {
		"source": SOURCE.IANA
	},
	"application/mmt-aei+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["maei"]
	},
	"application/mmt-usd+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["musd"]
	},
	"application/mods+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mods"]
	},
	"application/moss-keys": {
		"source": SOURCE.IANA
	},
	"application/moss-signature": {
		"source": SOURCE.IANA
	},
	"application/mosskey-data": {
		"source": SOURCE.IANA
	},
	"application/mosskey-request": {
		"source": SOURCE.IANA
	},
	"application/mp21": {
		"source": SOURCE.IANA,
		"extensions": ["m21","mp21"]
	},
	"application/mp4": {
		"source": SOURCE.IANA,
		"extensions": ["mp4s","m4p"]
	},
	"application/mpeg4-generic": {
		"source": SOURCE.IANA
	},
	"application/mpeg4-iod": {
		"source": SOURCE.IANA
	},
	"application/mpeg4-iod-xmt": {
		"source": SOURCE.IANA
	},
	"application/mrb-consumer+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/mrb-publish+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/msc-ivr+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/msc-mixer+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/msword": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["doc","dot"]
	},
	"application/mud+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/multipart-core": {
		"source": SOURCE.IANA
	},
	"application/mxf": {
		"source": SOURCE.IANA,
		"extensions": ["mxf"]
	},
	"application/n-quads": {
		"source": SOURCE.IANA,
		"extensions": ["nq"]
	},
	"application/n-triples": {
		"source": SOURCE.IANA,
		"extensions": ["nt"]
	},
	"application/nasdata": {
		"source": SOURCE.IANA
	},
	"application/news-checkgroups": {
		"source": SOURCE.IANA,
		"charset": "US-ASCII"
	},
	"application/news-groupinfo": {
		"source": SOURCE.IANA,
		"charset": "US-ASCII"
	},
	"application/news-transmission": {
		"source": SOURCE.IANA
	},
	"application/nlsml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/node": {
		"source": SOURCE.IANA,
		"extensions": ["cjs"]
	},
	"application/nss": {
		"source": SOURCE.IANA
	},
	"application/oauth-authz-req+jwt": {
		"source": SOURCE.IANA
	},
	"application/oblivious-dns-message": {
		"source": SOURCE.IANA
	},
	"application/ocsp-request": {
		"source": SOURCE.IANA
	},
	"application/ocsp-response": {
		"source": SOURCE.IANA
	},
	"application/octet-stream": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["bin","dms","lrf","mar","so","dist","distz","pkg","bpk","dump","elc","deploy","exe","dll","deb","dmg","iso","img","msi","msp","msm","buffer"]
	},
	"application/oda": {
		"source": SOURCE.IANA,
		"extensions": ["oda"]
	},
	"application/odm+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/odx": {
		"source": SOURCE.IANA
	},
	"application/oebps-package+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["opf"]
	},
	"application/ogg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["ogx"]
	},
	"application/omdoc+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["omdoc"]
	},
	"application/onenote": {
		"source": SOURCE.APACHE,
		"extensions": ["onetoc","onetoc2","onetmp","onepkg"]
	},
	"application/opc-nodeset+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/oscore": {
		"source": SOURCE.IANA
	},
	"application/oxps": {
		"source": SOURCE.IANA,
		"extensions": ["oxps"]
	},
	"application/p21": {
		"source": SOURCE.IANA
	},
	"application/p21+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/p2p-overlay+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["relo"]
	},
	"application/parityfec": {
		"source": SOURCE.IANA
	},
	"application/passport": {
		"source": SOURCE.IANA
	},
	"application/patch-ops-error+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xer"]
	},
	"application/pdf": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["pdf"]
	},
	"application/pdx": {
		"source": SOURCE.IANA
	},
	"application/pem-certificate-chain": {
		"source": SOURCE.IANA
	},
	"application/pgp-encrypted": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["pgp"]
	},
	"application/pgp-keys": {
		"source": SOURCE.IANA,
		"extensions": ["asc"]
	},
	"application/pgp-signature": {
		"source": SOURCE.IANA,
		"extensions": ["sig","asc"]
	},
	"application/pics-rules": {
		"source": SOURCE.APACHE,
		"extensions": ["prf"]
	},
	"application/pidf+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/pidf-diff+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/pkcs10": {
		"source": SOURCE.IANA,
		"extensions": ["p10"]
	},
	"application/pkcs12": {
		"source": SOURCE.IANA
	},
	"application/pkcs7-mime": {
		"source": SOURCE.IANA,
		"extensions": ["p7m","p7c"]
	},
	"application/pkcs7-signature": {
		"source": SOURCE.IANA,
		"extensions": ["p7s"]
	},
	"application/pkcs8": {
		"source": SOURCE.IANA,
		"extensions": ["p8"]
	},
	"application/pkcs8-encrypted": {
		"source": SOURCE.IANA
	},
	"application/pkix-attr-cert": {
		"source": SOURCE.IANA,
		"extensions": ["ac"]
	},
	"application/pkix-cert": {
		"source": SOURCE.IANA,
		"extensions": ["cer"]
	},
	"application/pkix-crl": {
		"source": SOURCE.IANA,
		"extensions": ["crl"]
	},
	"application/pkix-pkipath": {
		"source": SOURCE.IANA,
		"extensions": ["pkipath"]
	},
	"application/pkixcmp": {
		"source": SOURCE.IANA,
		"extensions": ["pki"]
	},
	"application/pls+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["pls"]
	},
	"application/poc-settings+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/postscript": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ai","eps","ps"]
	},
	"application/ppsp-tracker+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/problem+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/problem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/provenance+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["provx"]
	},
	"application/prs.alvestrand.titrax-sheet": {
		"source": SOURCE.IANA
	},
	"application/prs.cww": {
		"source": SOURCE.IANA,
		"extensions": ["cww"]
	},
	"application/prs.cyn": {
		"source": SOURCE.IANA,
		"charset": "7-BIT"
	},
	"application/prs.hpub+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/prs.nprend": {
		"source": SOURCE.IANA
	},
	"application/prs.plucker": {
		"source": SOURCE.IANA
	},
	"application/prs.rdf-xml-crypt": {
		"source": SOURCE.IANA
	},
	"application/prs.xsf+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xsf"]
	},
	"application/pskc+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["pskcxml"]
	},
	"application/pvd+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/qsig": {
		"source": SOURCE.IANA
	},
	"application/raml+yaml": {
		"compressible": true,
		"extensions": ["raml"]
	},
	"application/raptorfec": {
		"source": SOURCE.IANA
	},
	"application/rdap+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/rdf+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rdf","owl"]
	},
	"application/reginfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rif"]
	},
	"application/relax-ng-compact-syntax": {
		"source": SOURCE.IANA,
		"extensions": ["rnc"]
	},
	"application/remote-printing": {
		"source": SOURCE.IANA
	},
	"application/reputon+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/resource-lists+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rl"]
	},
	"application/resource-lists-diff+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rld"]
	},
	"application/rfc+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/riscos": {
		"source": SOURCE.IANA
	},
	"application/rlmi+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/rls-services+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rs"]
	},
	"application/route-apd+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rapd"]
	},
	"application/route-s-tsid+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["sls"]
	},
	"application/route-usd+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rusd"]
	},
	"application/rpki-ghostbusters": {
		"source": SOURCE.IANA,
		"extensions": ["gbr"]
	},
	"application/rpki-manifest": {
		"source": SOURCE.IANA,
		"extensions": ["mft"]
	},
	"application/rpki-publication": {
		"source": SOURCE.IANA
	},
	"application/rpki-roa": {
		"source": SOURCE.IANA,
		"extensions": ["roa"]
	},
	"application/rpki-updown": {
		"source": SOURCE.IANA
	},
	"application/rsd+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["rsd"]
	},
	"application/rss+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["rss"]
	},
	"application/rtf": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rtf"]
	},
	"application/rtploopback": {
		"source": SOURCE.IANA
	},
	"application/rtx": {
		"source": SOURCE.IANA
	},
	"application/samlassertion+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/samlmetadata+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sarif+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sarif-external-properties+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sbe": {
		"source": SOURCE.IANA
	},
	"application/sbml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["sbml"]
	},
	"application/scaip+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/scim+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/scvp-cv-request": {
		"source": SOURCE.IANA,
		"extensions": ["scq"]
	},
	"application/scvp-cv-response": {
		"source": SOURCE.IANA,
		"extensions": ["scs"]
	},
	"application/scvp-vp-request": {
		"source": SOURCE.IANA,
		"extensions": ["spq"]
	},
	"application/scvp-vp-response": {
		"source": SOURCE.IANA,
		"extensions": ["spp"]
	},
	"application/sdp": {
		"source": SOURCE.IANA,
		"extensions": ["sdp"]
	},
	"application/secevent+jwt": {
		"source": SOURCE.IANA
	},
	"application/senml+cbor": {
		"source": SOURCE.IANA
	},
	"application/senml+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/senml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["senmlx"]
	},
	"application/senml-etch+cbor": {
		"source": SOURCE.IANA
	},
	"application/senml-etch+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/senml-exi": {
		"source": SOURCE.IANA
	},
	"application/sensml+cbor": {
		"source": SOURCE.IANA
	},
	"application/sensml+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sensml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["sensmlx"]
	},
	"application/sensml-exi": {
		"source": SOURCE.IANA
	},
	"application/sep+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sep-exi": {
		"source": SOURCE.IANA
	},
	"application/session-info": {
		"source": SOURCE.IANA
	},
	"application/set-payment": {
		"source": SOURCE.IANA
	},
	"application/set-payment-initiation": {
		"source": SOURCE.IANA,
		"extensions": ["setpay"]
	},
	"application/set-registration": {
		"source": SOURCE.IANA
	},
	"application/set-registration-initiation": {
		"source": SOURCE.IANA,
		"extensions": ["setreg"]
	},
	"application/sgml": {
		"source": SOURCE.IANA
	},
	"application/sgml-open-catalog": {
		"source": SOURCE.IANA
	},
	"application/shf+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["shf"]
	},
	"application/sieve": {
		"source": SOURCE.IANA,
		"extensions": ["siv","sieve"]
	},
	"application/simple-filter+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/simple-message-summary": {
		"source": SOURCE.IANA
	},
	"application/simplesymbolcontainer": {
		"source": SOURCE.IANA
	},
	"application/sipc": {
		"source": SOURCE.IANA
	},
	"application/slate": {
		"source": SOURCE.IANA
	},
	"application/smil": {
		"source": SOURCE.APACHE
	},
	"application/smil+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["smi","smil"]
	},
	"application/smpte336m": {
		"source": SOURCE.IANA
	},
	"application/soap+fastinfoset": {
		"source": SOURCE.IANA
	},
	"application/soap+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sparql-query": {
		"source": SOURCE.IANA,
		"extensions": ["rq"]
	},
	"application/sparql-results+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["srx"]
	},
	"application/spdx+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/spirits-event+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/sql": {
		"source": SOURCE.IANA
	},
	"application/srgs": {
		"source": SOURCE.IANA,
		"extensions": ["gram"]
	},
	"application/srgs+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["grxml"]
	},
	"application/sru+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["sru"]
	},
	"application/ssdl+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["ssdl"]
	},
	"application/ssml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ssml"]
	},
	"application/stix+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/swid+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["swidtag"]
	},
	"application/tamp-apex-update": {
		"source": SOURCE.IANA
	},
	"application/tamp-apex-update-confirm": {
		"source": SOURCE.IANA
	},
	"application/tamp-community-update": {
		"source": SOURCE.IANA
	},
	"application/tamp-community-update-confirm": {
		"source": SOURCE.IANA
	},
	"application/tamp-error": {
		"source": SOURCE.IANA
	},
	"application/tamp-sequence-adjust": {
		"source": SOURCE.IANA
	},
	"application/tamp-sequence-adjust-confirm": {
		"source": SOURCE.IANA
	},
	"application/tamp-status-query": {
		"source": SOURCE.IANA
	},
	"application/tamp-status-response": {
		"source": SOURCE.IANA
	},
	"application/tamp-update": {
		"source": SOURCE.IANA
	},
	"application/tamp-update-confirm": {
		"source": SOURCE.IANA
	},
	"application/tar": {
		"compressible": true
	},
	"application/taxii+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/td+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/tei+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["tei","teicorpus"]
	},
	"application/tetra_isi": {
		"source": SOURCE.IANA
	},
	"application/thraud+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["tfi"]
	},
	"application/timestamp-query": {
		"source": SOURCE.IANA
	},
	"application/timestamp-reply": {
		"source": SOURCE.IANA
	},
	"application/timestamped-data": {
		"source": SOURCE.IANA,
		"extensions": ["tsd"]
	},
	"application/tlsrpt+gzip": {
		"source": SOURCE.IANA
	},
	"application/tlsrpt+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/tnauthlist": {
		"source": SOURCE.IANA
	},
	"application/token-introspection+jwt": {
		"source": SOURCE.IANA
	},
	"application/toml": {
		"compressible": true,
		"extensions": ["toml"]
	},
	"application/trickle-ice-sdpfrag": {
		"source": SOURCE.IANA
	},
	"application/trig": {
		"source": SOURCE.IANA,
		"extensions": ["trig"]
	},
	"application/ttml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ttml"]
	},
	"application/tve-trigger": {
		"source": SOURCE.IANA
	},
	"application/tzif": {
		"source": SOURCE.IANA
	},
	"application/tzif-leap": {
		"source": SOURCE.IANA
	},
	"application/ubjson": {
		"compressible": false,
		"extensions": ["ubj"]
	},
	"application/ulpfec": {
		"source": SOURCE.IANA
	},
	"application/urc-grpsheet+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/urc-ressheet+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rsheet"]
	},
	"application/urc-targetdesc+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["td"]
	},
	"application/urc-uisocketdesc+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vcard+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vcard+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vemmi": {
		"source": SOURCE.IANA
	},
	"application/vividence.scriptfile": {
		"source": SOURCE.APACHE
	},
	"application/vnd.1000minds.decision-model+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["1km"]
	},
	"application/vnd.3gpp-prose+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp-prose-pc3ch+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp-v2x-local-service-information": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.5gnas": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.access-transfer-events+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.bsf+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.gmop+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.gtpc": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.interworking-data": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.lpp": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.mc-signalling-ear": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.mcdata-affiliation-command+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-msgstore-ctrl-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-payload": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.mcdata-regroup+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-service-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-signalling": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.mcdata-ue-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcdata-user-profile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-affiliation-command+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-floor-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-location-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-mbms-usage-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-service-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-signed+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-ue-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-ue-init-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcptt-user-profile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-affiliation-command+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-location-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-mbms-usage-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-service-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-transmission-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-ue-config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mcvideo-user-profile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.mid-call+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.ngap": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.pfcp": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.pic-bw-large": {
		"source": SOURCE.IANA,
		"extensions": ["plb"]
	},
	"application/vnd.3gpp.pic-bw-small": {
		"source": SOURCE.IANA,
		"extensions": ["psb"]
	},
	"application/vnd.3gpp.pic-bw-var": {
		"source": SOURCE.IANA,
		"extensions": ["pvb"]
	},
	"application/vnd.3gpp.s1ap": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.sms": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp.sms+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.srvcc-ext+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.srvcc-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.state-and-event-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp.ussd+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp2.bcmcsinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.3gpp2.sms": {
		"source": SOURCE.IANA
	},
	"application/vnd.3gpp2.tcap": {
		"source": SOURCE.IANA,
		"extensions": ["tcap"]
	},
	"application/vnd.3lightssoftware.imagescal": {
		"source": SOURCE.IANA
	},
	"application/vnd.3m.post-it-notes": {
		"source": SOURCE.IANA,
		"extensions": ["pwn"]
	},
	"application/vnd.accpac.simply.aso": {
		"source": SOURCE.IANA,
		"extensions": ["aso"]
	},
	"application/vnd.accpac.simply.imp": {
		"source": SOURCE.IANA,
		"extensions": ["imp"]
	},
	"application/vnd.acucobol": {
		"source": SOURCE.IANA,
		"extensions": ["acu"]
	},
	"application/vnd.acucorp": {
		"source": SOURCE.IANA,
		"extensions": ["atc","acutc"]
	},
	"application/vnd.adobe.air-application-installer-package+zip": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["air"]
	},
	"application/vnd.adobe.flash.movie": {
		"source": SOURCE.IANA
	},
	"application/vnd.adobe.formscentral.fcdt": {
		"source": SOURCE.IANA,
		"extensions": ["fcdt"]
	},
	"application/vnd.adobe.fxp": {
		"source": SOURCE.IANA,
		"extensions": ["fxp","fxpl"]
	},
	"application/vnd.adobe.partial-upload": {
		"source": SOURCE.IANA
	},
	"application/vnd.adobe.xdp+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xdp"]
	},
	"application/vnd.adobe.xfdf": {
		"source": SOURCE.APACHE,
		"extensions": ["xfdf"]
	},
	"application/vnd.aether.imp": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.afplinedata": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.afplinedata-pagedef": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.cmoca-cmresource": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.foca-charset": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.foca-codedfont": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.foca-codepage": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-cmtable": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-formdef": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-mediummap": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-objectcontainer": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-overlay": {
		"source": SOURCE.IANA
	},
	"application/vnd.afpc.modca-pagesegment": {
		"source": SOURCE.IANA
	},
	"application/vnd.age": {
		"source": SOURCE.IANA,
		"extensions": ["age"]
	},
	"application/vnd.ah-barcode": {
		"source": SOURCE.APACHE
	},
	"application/vnd.ahead.space": {
		"source": SOURCE.IANA,
		"extensions": ["ahead"]
	},
	"application/vnd.airzip.filesecure.azf": {
		"source": SOURCE.IANA,
		"extensions": ["azf"]
	},
	"application/vnd.airzip.filesecure.azs": {
		"source": SOURCE.IANA,
		"extensions": ["azs"]
	},
	"application/vnd.amadeus+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.amazon.ebook": {
		"source": SOURCE.APACHE,
		"extensions": ["azw"]
	},
	"application/vnd.amazon.mobi8-ebook": {
		"source": SOURCE.IANA
	},
	"application/vnd.americandynamics.acc": {
		"source": SOURCE.IANA,
		"extensions": ["acc"]
	},
	"application/vnd.amiga.ami": {
		"source": SOURCE.IANA,
		"extensions": ["ami"]
	},
	"application/vnd.amundsen.maze+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.android.ota": {
		"source": SOURCE.IANA
	},
	"application/vnd.android.package-archive": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["apk"]
	},
	"application/vnd.anki": {
		"source": SOURCE.IANA
	},
	"application/vnd.anser-web-certificate-issue-initiation": {
		"source": SOURCE.IANA,
		"extensions": ["cii"]
	},
	"application/vnd.anser-web-funds-transfer-initiation": {
		"source": SOURCE.APACHE,
		"extensions": ["fti"]
	},
	"application/vnd.antix.game-component": {
		"source": SOURCE.IANA,
		"extensions": ["atx"]
	},
	"application/vnd.apache.arrow.file": {
		"source": SOURCE.IANA
	},
	"application/vnd.apache.arrow.stream": {
		"source": SOURCE.IANA
	},
	"application/vnd.apache.thrift.binary": {
		"source": SOURCE.IANA
	},
	"application/vnd.apache.thrift.compact": {
		"source": SOURCE.IANA
	},
	"application/vnd.apache.thrift.json": {
		"source": SOURCE.IANA
	},
	"application/vnd.api+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.aplextor.warrp+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.apothekende.reservation+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.apple.installer+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mpkg"]
	},
	"application/vnd.apple.keynote": {
		"source": SOURCE.IANA,
		"extensions": ["key"]
	},
	"application/vnd.apple.mpegurl": {
		"source": SOURCE.IANA,
		"extensions": ["m3u8"]
	},
	"application/vnd.apple.numbers": {
		"source": SOURCE.IANA,
		"extensions": ["numbers"]
	},
	"application/vnd.apple.pages": {
		"source": SOURCE.IANA,
		"extensions": ["pages"]
	},
	"application/vnd.apple.pkpass": {
		"compressible": false,
		"extensions": ["pkpass"]
	},
	"application/vnd.arastra.swi": {
		"source": SOURCE.APACHE
	},
	"application/vnd.aristanetworks.swi": {
		"source": SOURCE.IANA,
		"extensions": ["swi"]
	},
	"application/vnd.artisan+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.artsquare": {
		"source": SOURCE.IANA
	},
	"application/vnd.astraea-software.iota": {
		"source": SOURCE.IANA,
		"extensions": ["iota"]
	},
	"application/vnd.audiograph": {
		"source": SOURCE.IANA,
		"extensions": ["aep"]
	},
	"application/vnd.autopackage": {
		"source": SOURCE.IANA
	},
	"application/vnd.avalon+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.avistar+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.balsamiq.bmml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["bmml"]
	},
	"application/vnd.balsamiq.bmpr": {
		"source": SOURCE.IANA
	},
	"application/vnd.banana-accounting": {
		"source": SOURCE.IANA
	},
	"application/vnd.bbf.usp.error": {
		"source": SOURCE.IANA
	},
	"application/vnd.bbf.usp.msg": {
		"source": SOURCE.IANA
	},
	"application/vnd.bbf.usp.msg+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.bekitzur-stech+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.belightsoft.lhzd+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.bint.med-content": {
		"source": SOURCE.IANA
	},
	"application/vnd.biopax.rdf+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.blink-iraw_db-value-wrapper": {
		"source": SOURCE.IANA
	},
	"application/vnd.blueice.multipass": {
		"source": SOURCE.IANA,
		"extensions": ["mpm"]
	},
	"application/vnd.bluetooth.ep.oob": {
		"source": SOURCE.IANA
	},
	"application/vnd.bluetooth.le.oob": {
		"source": SOURCE.IANA
	},
	"application/vnd.bmi": {
		"source": SOURCE.IANA,
		"extensions": ["bmi"]
	},
	"application/vnd.bpf": {
		"source": SOURCE.IANA
	},
	"application/vnd.bpf3": {
		"source": SOURCE.IANA
	},
	"application/vnd.businessobjects": {
		"source": SOURCE.IANA,
		"extensions": ["rep"]
	},
	"application/vnd.byu.uapi+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cab-jscript": {
		"source": SOURCE.IANA
	},
	"application/vnd.canon-cpdl": {
		"source": SOURCE.IANA
	},
	"application/vnd.canon-lips": {
		"source": SOURCE.IANA
	},
	"application/vnd.capasystems-pg+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cendio.thinlinc.clientconf": {
		"source": SOURCE.IANA
	},
	"application/vnd.century-systems.tcp_stream": {
		"source": SOURCE.IANA
	},
	"application/vnd.chemdraw+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["cdxml"]
	},
	"application/vnd.chess-pgn": {
		"source": SOURCE.IANA
	},
	"application/vnd.chipnuts.karaoke-mmd": {
		"source": SOURCE.IANA,
		"extensions": ["mmd"]
	},
	"application/vnd.ciedi": {
		"source": SOURCE.IANA
	},
	"application/vnd.cinderella": {
		"source": SOURCE.IANA,
		"extensions": ["cdy"]
	},
	"application/vnd.cirpack.isdn-ext": {
		"source": SOURCE.IANA
	},
	"application/vnd.citationstyles.style+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["csl"]
	},
	"application/vnd.claymore": {
		"source": SOURCE.IANA,
		"extensions": ["cla"]
	},
	"application/vnd.cloanto.rp9": {
		"source": SOURCE.IANA,
		"extensions": ["rp9"]
	},
	"application/vnd.clonk.c4group": {
		"source": SOURCE.IANA,
		"extensions": ["c4g","c4d","c4f","c4p","c4u"]
	},
	"application/vnd.cluetrust.cartomobile-config": {
		"source": SOURCE.IANA,
		"extensions": ["c11amc"]
	},
	"application/vnd.cluetrust.cartomobile-config-pkg": {
		"source": SOURCE.IANA,
		"extensions": ["c11amz"]
	},
	"application/vnd.coffeescript": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.document": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.document-template": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.presentation": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.presentation-template": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.spreadsheet": {
		"source": SOURCE.IANA
	},
	"application/vnd.collabio.xodocuments.spreadsheet-template": {
		"source": SOURCE.IANA
	},
	"application/vnd.collection+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.collection.doc+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.collection.next+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.comicbook+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.comicbook-rar": {
		"source": SOURCE.IANA
	},
	"application/vnd.commerce-battelle": {
		"source": SOURCE.IANA
	},
	"application/vnd.commonspace": {
		"source": SOURCE.IANA,
		"extensions": ["csp"]
	},
	"application/vnd.contact.cmsg": {
		"source": SOURCE.IANA,
		"extensions": ["craw_dbcmsg"]
	},
	"application/vnd.coreos.ignition+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cosmocaller": {
		"source": SOURCE.IANA,
		"extensions": ["cmc"]
	},
	"application/vnd.crick.clicker": {
		"source": SOURCE.IANA,
		"extensions": ["clkx"]
	},
	"application/vnd.crick.clicker.keyboard": {
		"source": SOURCE.IANA,
		"extensions": ["clkk"]
	},
	"application/vnd.crick.clicker.palette": {
		"source": SOURCE.IANA,
		"extensions": ["clkp"]
	},
	"application/vnd.crick.clicker.template": {
		"source": SOURCE.IANA,
		"extensions": ["clkt"]
	},
	"application/vnd.crick.clicker.worraw_dbank": {
		"source": SOURCE.IANA,
		"extensions": ["clkw"]
	},
	"application/vnd.criticaltools.wbs+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wbs"]
	},
	"application/vnd.cryptii.pipe+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.crypto-shade-file": {
		"source": SOURCE.IANA
	},
	"application/vnd.cryptomator.encrypted": {
		"source": SOURCE.IANA
	},
	"application/vnd.cryptomator.vault": {
		"source": SOURCE.IANA
	},
	"application/vnd.ctc-posml": {
		"source": SOURCE.IANA,
		"extensions": ["pml"]
	},
	"application/vnd.ctct.ws+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cups-pdf": {
		"source": SOURCE.IANA
	},
	"application/vnd.cups-postscript": {
		"source": SOURCE.IANA
	},
	"application/vnd.cups-ppd": {
		"source": SOURCE.IANA,
		"extensions": ["ppd"]
	},
	"application/vnd.cups-raster": {
		"source": SOURCE.IANA
	},
	"application/vnd.cups-raw": {
		"source": SOURCE.IANA
	},
	"application/vnd.curl": {
		"source": SOURCE.IANA
	},
	"application/vnd.curl.car": {
		"source": SOURCE.APACHE,
		"extensions": ["car"]
	},
	"application/vnd.curl.pcurl": {
		"source": SOURCE.APACHE,
		"extensions": ["pcurl"]
	},
	"application/vnd.cyan.dean.root+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cybank": {
		"source": SOURCE.IANA
	},
	"application/vnd.cyclonedx+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.cyclonedx+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.d2l.coursepackage1p0+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.d3m-dataset": {
		"source": SOURCE.IANA
	},
	"application/vnd.d3m-problem": {
		"source": SOURCE.IANA
	},
	"application/vnd.dart": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["dart"]
	},
	"application/vnd.data-vision.rdz": {
		"source": SOURCE.IANA,
		"extensions": ["rdz"]
	},
	"application/vnd.datapackage+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dataresource+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.raw_dbf": {
		"source": SOURCE.IANA,
		"extensions": ["raw_dbf"]
	},
	"application/vnd.debian.binary-package": {
		"source": SOURCE.IANA
	},
	"application/vnd.dece.data": {
		"source": SOURCE.IANA,
		"extensions": ["uvf","uvvf","uvd","uvvd"]
	},
	"application/vnd.dece.ttml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["uvt","uvvt"]
	},
	"application/vnd.dece.unspecified": {
		"source": SOURCE.IANA,
		"extensions": ["uvx","uvvx"]
	},
	"application/vnd.dece.zip": {
		"source": SOURCE.IANA,
		"extensions": ["uvz","uvvz"]
	},
	"application/vnd.denovo.fcselayout-link": {
		"source": SOURCE.IANA,
		"extensions": ["fe_launch"]
	},
	"application/vnd.desmume.movie": {
		"source": SOURCE.IANA
	},
	"application/vnd.dir-bi.plate-dl-nosuffix": {
		"source": SOURCE.IANA
	},
	"application/vnd.dm.delegation+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dna": {
		"source": SOURCE.IANA,
		"extensions": ["dna"]
	},
	"application/vnd.document+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dolby.mlp": {
		"source": SOURCE.APACHE,
		"extensions": ["mlp"]
	},
	"application/vnd.dolby.mobile.1": {
		"source": SOURCE.IANA
	},
	"application/vnd.dolby.mobile.2": {
		"source": SOURCE.IANA
	},
	"application/vnd.doremir.scorecloud-binary-document": {
		"source": SOURCE.IANA
	},
	"application/vnd.dpgraph": {
		"source": SOURCE.IANA,
		"extensions": ["dpg"]
	},
	"application/vnd.dreamfactory": {
		"source": SOURCE.IANA,
		"extensions": ["dfac"]
	},
	"application/vnd.drive+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ds-keypoint": {
		"source": SOURCE.APACHE,
		"extensions": ["kpxx"]
	},
	"application/vnd.dtg.local": {
		"source": SOURCE.IANA
	},
	"application/vnd.dtg.local.flash": {
		"source": SOURCE.IANA
	},
	"application/vnd.dtg.local.html": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ait": {
		"source": SOURCE.IANA,
		"extensions": ["ait"]
	},
	"application/vnd.dvb.dvbisl+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.dvbj": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.esgcontainer": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ipdcdftnotifaccess": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ipdcesgaccess": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ipdcesgaccess2": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ipdcesgpdd": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.ipdcroaming": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.iptv.alfec-base": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.iptv.alfec-enhancement": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.notif-aggregate-root+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-container+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-generic+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-ia-msglist+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-ia-registration-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-ia-registration-response+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.notif-init+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.dvb.pfr": {
		"source": SOURCE.IANA
	},
	"application/vnd.dvb.service": {
		"source": SOURCE.IANA,
		"extensions": ["svc"]
	},
	"application/vnd.dxr": {
		"source": SOURCE.IANA
	},
	"application/vnd.dynageo": {
		"source": SOURCE.IANA,
		"extensions": ["geo"]
	},
	"application/vnd.dzr": {
		"source": SOURCE.IANA
	},
	"application/vnd.easykaraoke.cdgdownload": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecdis-update": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecip.rlp": {
		"source": SOURCE.IANA
	},
	"application/vnd.eclipse.ditto+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ecowin.chart": {
		"source": SOURCE.IANA,
		"extensions": ["mag"]
	},
	"application/vnd.ecowin.filerequest": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecowin.fileupdate": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecowin.series": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecowin.seriesrequest": {
		"source": SOURCE.IANA
	},
	"application/vnd.ecowin.seriesupdate": {
		"source": SOURCE.IANA
	},
	"application/vnd.efi.img": {
		"source": SOURCE.IANA
	},
	"application/vnd.efi.iso": {
		"source": SOURCE.IANA
	},
	"application/vnd.emclient.accessrequest+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.enliven": {
		"source": SOURCE.IANA,
		"extensions": ["nml"]
	},
	"application/vnd.enphase.envoy": {
		"source": SOURCE.IANA
	},
	"application/vnd.eprints.data+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.epson.esf": {
		"source": SOURCE.IANA,
		"extensions": ["esf"]
	},
	"application/vnd.epson.msf": {
		"source": SOURCE.IANA,
		"extensions": ["msf"]
	},
	"application/vnd.epson.quickanime": {
		"source": SOURCE.IANA,
		"extensions": ["qam"]
	},
	"application/vnd.epson.salt": {
		"source": SOURCE.IANA,
		"extensions": ["slt"]
	},
	"application/vnd.epson.ssf": {
		"source": SOURCE.IANA,
		"extensions": ["ssf"]
	},
	"application/vnd.ericsson.quickcall": {
		"source": SOURCE.IANA
	},
	"application/vnd.espass-espass+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.eszigno3+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["es3","et3"]
	},
	"application/vnd.etsi.aoc+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.asic-e+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.etsi.asic-s+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.etsi.cug+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvcommand+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvdiscovery+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvprofile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvsad-bc+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvsad-cod+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvsad-npvr+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvservice+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvsync+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.iptvueprofile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.mcid+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.mheg5": {
		"source": SOURCE.IANA
	},
	"application/vnd.etsi.overload-control-policy-dataset+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.pstn+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.sci+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.simservs+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.timestamp-token": {
		"source": SOURCE.IANA
	},
	"application/vnd.etsi.tsl+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.etsi.tsl.der": {
		"source": SOURCE.IANA
	},
	"application/vnd.eu.kasparian.car+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.eudora.data": {
		"source": SOURCE.IANA
	},
	"application/vnd.evolv.ecig.profile": {
		"source": SOURCE.IANA
	},
	"application/vnd.evolv.ecig.settings": {
		"source": SOURCE.IANA
	},
	"application/vnd.evolv.ecig.theme": {
		"source": SOURCE.IANA
	},
	"application/vnd.exstream-empower+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.exstream-package": {
		"source": SOURCE.IANA
	},
	"application/vnd.ezpix-album": {
		"source": SOURCE.IANA,
		"extensions": ["ez2"]
	},
	"application/vnd.ezpix-package": {
		"source": SOURCE.IANA,
		"extensions": ["ez3"]
	},
	"application/vnd.f-secure.mobile": {
		"source": SOURCE.IANA
	},
	"application/vnd.familysearch.gedcom+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.fastcopy-disk-image": {
		"source": SOURCE.IANA
	},
	"application/vnd.fdf": {
		"source": SOURCE.APACHE,
		"extensions": ["fdf"]
	},
	"application/vnd.fdsn.mseed": {
		"source": SOURCE.IANA,
		"extensions": ["mseed"]
	},
	"application/vnd.fdsn.seed": {
		"source": SOURCE.IANA,
		"extensions": ["seed","dataless"]
	},
	"application/vnd.ffsns": {
		"source": SOURCE.IANA
	},
	"application/vnd.ficlab.flb+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.filmit.zfc": {
		"source": SOURCE.IANA
	},
	"application/vnd.fints": {
		"source": SOURCE.IANA
	},
	"application/vnd.firemonkeys.cloudcell": {
		"source": SOURCE.IANA
	},
	"application/vnd.flographit": {
		"source": SOURCE.IANA,
		"extensions": ["gph"]
	},
	"application/vnd.fluxtime.clip": {
		"source": SOURCE.IANA,
		"extensions": ["ftc"]
	},
	"application/vnd.font-fontforge-sfd": {
		"source": SOURCE.IANA
	},
	"application/vnd.framemaker": {
		"source": SOURCE.IANA,
		"extensions": ["fm","frame","maker","book"]
	},
	"application/vnd.frogans.fnc": {
		"source": SOURCE.APACHE,
		"extensions": ["fnc"]
	},
	"application/vnd.frogans.ltf": {
		"source": SOURCE.APACHE,
		"extensions": ["ltf"]
	},
	"application/vnd.fsc.weblaunch": {
		"source": SOURCE.IANA,
		"extensions": ["fsc"]
	},
	"application/vnd.fujifilm.fb.docuworks": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujifilm.fb.docuworks.binder": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujifilm.fb.docuworks.container": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujifilm.fb.jfi+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.fujitsu.oasys": {
		"source": SOURCE.IANA,
		"extensions": ["oas"]
	},
	"application/vnd.fujitsu.oasys2": {
		"source": SOURCE.IANA,
		"extensions": ["oa2"]
	},
	"application/vnd.fujitsu.oasys3": {
		"source": SOURCE.IANA,
		"extensions": ["oa3"]
	},
	"application/vnd.fujitsu.oasysgp": {
		"source": SOURCE.IANA,
		"extensions": ["fg5"]
	},
	"application/vnd.fujitsu.oasysprs": {
		"source": SOURCE.IANA,
		"extensions": ["bh2"]
	},
	"application/vnd.fujixerox.art-ex": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujixerox.art4": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujixerox.ddd": {
		"source": SOURCE.IANA,
		"extensions": ["ddd"]
	},
	"application/vnd.fujixerox.docuworks": {
		"source": SOURCE.IANA,
		"extensions": ["xdw"]
	},
	"application/vnd.fujixerox.docuworks.binder": {
		"source": SOURCE.IANA,
		"extensions": ["xbd"]
	},
	"application/vnd.fujixerox.docuworks.container": {
		"source": SOURCE.IANA
	},
	"application/vnd.fujixerox.hbpl": {
		"source": SOURCE.IANA
	},
	"application/vnd.fut-misnet": {
		"source": SOURCE.IANA
	},
	"application/vnd.futoin+cbor": {
		"source": SOURCE.IANA
	},
	"application/vnd.futoin+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.fuzzysheet": {
		"source": SOURCE.IANA,
		"extensions": ["fzs"]
	},
	"application/vnd.genomatix.tuxedo": {
		"source": SOURCE.IANA,
		"extensions": ["txd"]
	},
	"application/vnd.genozip": {
		"source": SOURCE.IANA
	},
	"application/vnd.gentics.grd+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.geo+json": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.geocube+xml": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.geogebra.file": {
		"source": SOURCE.IANA,
		"extensions": ["ggb"]
	},
	"application/vnd.geogebra.slides": {
		"source": SOURCE.IANA
	},
	"application/vnd.geogebra.tool": {
		"source": SOURCE.IANA,
		"extensions": ["ggt"]
	},
	"application/vnd.geometry-explorer": {
		"source": SOURCE.IANA,
		"extensions": ["gex","gre"]
	},
	"application/vnd.geonext": {
		"source": SOURCE.IANA,
		"extensions": ["gxt"]
	},
	"application/vnd.geoplan": {
		"source": SOURCE.IANA,
		"extensions": ["g2w"]
	},
	"application/vnd.geospace": {
		"source": SOURCE.IANA,
		"extensions": ["g3w"]
	},
	"application/vnd.gerber": {
		"source": SOURCE.IANA
	},
	"application/vnd.globalplatform.card-content-mgt": {
		"source": SOURCE.IANA
	},
	"application/vnd.globalplatform.card-content-mgt-response": {
		"source": SOURCE.IANA
	},
	"application/vnd.gmx": {
		"source": SOURCE.IANA,
		"extensions": ["gmx"]
	},
	"application/vnd.gnu.taler.exchange+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.gnu.taler.merchant+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.google-apps.document": {
		"compressible": false,
		"extensions": ["gdoc"]
	},
	"application/vnd.google-apps.presentation": {
		"compressible": false,
		"extensions": ["gslides"]
	},
	"application/vnd.google-apps.spreadsheet": {
		"compressible": false,
		"extensions": ["gsheet"]
	},
	"application/vnd.google-earth.kml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["kml"]
	},
	"application/vnd.google-earth.kmz": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["kmz"]
	},
	"application/vnd.gov.sk.e-form+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.gov.sk.e-form+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.gov.sk.xmldatacontainer+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.grafeq": {
		"source": SOURCE.IANA,
		"extensions": ["gqf","gqs"]
	},
	"application/vnd.gridmp": {
		"source": SOURCE.IANA
	},
	"application/vnd.groove-account": {
		"source": SOURCE.IANA,
		"extensions": ["gac"]
	},
	"application/vnd.groove-help": {
		"source": SOURCE.IANA,
		"extensions": ["ghf"]
	},
	"application/vnd.groove-identity-message": {
		"source": SOURCE.IANA,
		"extensions": ["gim"]
	},
	"application/vnd.groove-injector": {
		"source": SOURCE.IANA,
		"extensions": ["grv"]
	},
	"application/vnd.groove-tool-message": {
		"source": SOURCE.IANA,
		"extensions": ["gtm"]
	},
	"application/vnd.groove-tool-template": {
		"source": SOURCE.IANA,
		"extensions": ["tpl"]
	},
	"application/vnd.groove-vcard": {
		"source": SOURCE.IANA,
		"extensions": ["vcg"]
	},
	"application/vnd.hal+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hal+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["hal"]
	},
	"application/vnd.handheld-entertainment+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["zmm"]
	},
	"application/vnd.hbci": {
		"source": SOURCE.IANA,
		"extensions": ["hbci"]
	},
	"application/vnd.hc+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hcl-bireports": {
		"source": SOURCE.IANA
	},
	"application/vnd.hdt": {
		"source": SOURCE.IANA
	},
	"application/vnd.heroku+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hhe.lesson-player": {
		"source": SOURCE.IANA,
		"extensions": ["les"]
	},
	"application/vnd.hp-hpgl": {
		"source": SOURCE.IANA,
		"extensions": ["hpgl"]
	},
	"application/vnd.hp-hpid": {
		"source": SOURCE.IANA,
		"extensions": ["hpid"]
	},
	"application/vnd.hp-hps": {
		"source": SOURCE.IANA,
		"extensions": ["hps"]
	},
	"application/vnd.hp-jlyt": {
		"source": SOURCE.IANA,
		"extensions": ["jlt"]
	},
	"application/vnd.hp-pcl": {
		"source": SOURCE.IANA,
		"extensions": ["pcl"]
	},
	"application/vnd.hp-pclxl": {
		"source": SOURCE.IANA,
		"extensions": ["pclxl"]
	},
	"application/vnd.httphone": {
		"source": SOURCE.IANA
	},
	"application/vnd.hydrostatix.sof-data": {
		"source": SOURCE.IANA,
		"extensions": ["sfd-hdstx"]
	},
	"application/vnd.hyper+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hyper-item+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hyperdrive+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.hzn-3d-crossword": {
		"source": SOURCE.IANA
	},
	"application/vnd.ibm.afplinedata": {
		"source": SOURCE.APACHE
	},
	"application/vnd.ibm.electronic-media": {
		"source": SOURCE.IANA
	},
	"application/vnd.ibm.minipay": {
		"source": SOURCE.IANA,
		"extensions": ["mpy"]
	},
	"application/vnd.ibm.modcap": {
		"source": SOURCE.APACHE,
		"extensions": ["afp","listafp","list3820"]
	},
	"application/vnd.ibm.rights-management": {
		"source": SOURCE.IANA,
		"extensions": ["irm"]
	},
	"application/vnd.ibm.secure-container": {
		"source": SOURCE.IANA,
		"extensions": ["sc"]
	},
	"application/vnd.iccprofile": {
		"source": SOURCE.IANA,
		"extensions": ["icc","icm"]
	},
	"application/vnd.ieee.1905": {
		"source": SOURCE.IANA
	},
	"application/vnd.igloader": {
		"source": SOURCE.IANA,
		"extensions": ["igl"]
	},
	"application/vnd.imagemeter.folder+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.imagemeter.image+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.immervision-ivp": {
		"source": SOURCE.IANA,
		"extensions": ["ivp"]
	},
	"application/vnd.immervision-ivu": {
		"source": SOURCE.IANA,
		"extensions": ["ivu"]
	},
	"application/vnd.ims.imsccv1p1": {
		"source": SOURCE.IANA
	},
	"application/vnd.ims.imsccv1p2": {
		"source": SOURCE.IANA
	},
	"application/vnd.ims.imsccv1p3": {
		"source": SOURCE.IANA
	},
	"application/vnd.ims.lis.v2.result+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ims.lti.v2.toolconsumerprofile+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ims.lti.v2.toolproxy+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ims.lti.v2.toolproxy.id+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ims.lti.v2.toolsettings+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ims.lti.v2.toolsettings.simple+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.informedcontrol.rms+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.informix-visionary": {
		"source": SOURCE.APACHE
	},
	"application/vnd.infotech.project": {
		"source": SOURCE.IANA
	},
	"application/vnd.infotech.project+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.innopath.wamp.notification": {
		"source": SOURCE.IANA
	},
	"application/vnd.insors.igm": {
		"source": SOURCE.IANA,
		"extensions": ["igm"]
	},
	"application/vnd.intercon.formnet": {
		"source": SOURCE.IANA,
		"extensions": ["xpw","xpx"]
	},
	"application/vnd.intergeo": {
		"source": SOURCE.IANA,
		"extensions": ["i2g"]
	},
	"application/vnd.intertrust.digibox": {
		"source": SOURCE.IANA
	},
	"application/vnd.intertrust.nncp": {
		"source": SOURCE.IANA
	},
	"application/vnd.intu.qbo": {
		"source": SOURCE.IANA,
		"extensions": ["qbo"]
	},
	"application/vnd.intu.qfx": {
		"source": SOURCE.IANA,
		"extensions": ["qfx"]
	},
	"application/vnd.ipld.car": {
		"source": SOURCE.IANA
	},
	"application/vnd.ipld.raw": {
		"source": SOURCE.IANA
	},
	"application/vnd.iptc.g2.catalogitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.conceptitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.knowledgeitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.newsitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.newsmessage+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.packageitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.iptc.g2.planningitem+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ipunplugged.rcprofile": {
		"source": SOURCE.IANA,
		"extensions": ["rcprofile"]
	},
	"application/vnd.irepository.package+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["irp"]
	},
	"application/vnd.is-xpr": {
		"source": SOURCE.IANA,
		"extensions": ["xpr"]
	},
	"application/vnd.isac.fcs": {
		"source": SOURCE.IANA,
		"extensions": ["fcs"]
	},
	"application/vnd.iso11783-10+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.jam": {
		"source": SOURCE.IANA,
		"extensions": ["jam"]
	},
	"application/vnd.japannet-directory-service": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-jpnstore-wakeup": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-payment-wakeup": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-registration": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-registration-wakeup": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-setstore-wakeup": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-verification": {
		"source": SOURCE.IANA
	},
	"application/vnd.japannet-verification-wakeup": {
		"source": SOURCE.IANA
	},
	"application/vnd.jcp.javame.midlet-rms": {
		"source": SOURCE.IANA,
		"extensions": ["rms"]
	},
	"application/vnd.jisp": {
		"source": SOURCE.IANA,
		"extensions": ["jisp"]
	},
	"application/vnd.joost.joda-archive": {
		"source": SOURCE.IANA,
		"extensions": ["joda"]
	},
	"application/vnd.jsk.isdn-ngn": {
		"source": SOURCE.IANA
	},
	"application/vnd.kahootz": {
		"source": SOURCE.IANA,
		"extensions": ["ktz","ktr"]
	},
	"application/vnd.kde.karbon": {
		"source": SOURCE.IANA,
		"extensions": ["karbon"]
	},
	"application/vnd.kde.kchart": {
		"source": SOURCE.IANA,
		"extensions": ["chrt"]
	},
	"application/vnd.kde.kformula": {
		"source": SOURCE.IANA,
		"extensions": ["kfo"]
	},
	"application/vnd.kde.kivio": {
		"source": SOURCE.IANA,
		"extensions": ["flw"]
	},
	"application/vnd.kde.kontour": {
		"source": SOURCE.IANA,
		"extensions": ["kon"]
	},
	"application/vnd.kde.kpresenter": {
		"source": SOURCE.IANA,
		"extensions": ["kpr","kpt"]
	},
	"application/vnd.kde.kspread": {
		"source": SOURCE.IANA,
		"extensions": ["ksp"]
	},
	"application/vnd.kde.kword": {
		"source": SOURCE.IANA,
		"extensions": ["kwd","kwt"]
	},
	"application/vnd.kenameaapp": {
		"source": SOURCE.IANA,
		"extensions": ["htke"]
	},
	"application/vnd.kidspiration": {
		"source": SOURCE.IANA,
		"extensions": ["kia"]
	},
	"application/vnd.kinar": {
		"source": SOURCE.IANA,
		"extensions": ["kne","knp"]
	},
	"application/vnd.koan": {
		"source": SOURCE.IANA,
		"extensions": ["skp","skd","skt","skm"]
	},
	"application/vnd.kodak-descriptor": {
		"source": SOURCE.IANA,
		"extensions": ["sse"]
	},
	"application/vnd.las": {
		"source": SOURCE.IANA
	},
	"application/vnd.las.las+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.las.las+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["lasxml"]
	},
	"application/vnd.laszip": {
		"source": SOURCE.IANA
	},
	"application/vnd.leap+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.liberty-request+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.llamagraphics.life-balance.desktop": {
		"source": SOURCE.IANA,
		"extensions": ["lbd"]
	},
	"application/vnd.llamagraphics.life-balance.exchange+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["lbe"]
	},
	"application/vnd.logipipe.circuit+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.loom": {
		"source": SOURCE.IANA
	},
	"application/vnd.lotus-1-2-3": {
		"source": SOURCE.IANA,
		"extensions": ["123"]
	},
	"application/vnd.lotus-approach": {
		"source": SOURCE.IANA,
		"extensions": ["apr"]
	},
	"application/vnd.lotus-freelance": {
		"source": SOURCE.IANA,
		"extensions": ["pre"]
	},
	"application/vnd.lotus-notes": {
		"source": SOURCE.IANA,
		"extensions": ["nsf"]
	},
	"application/vnd.lotus-organizer": {
		"source": SOURCE.IANA,
		"extensions": ["org"]
	},
	"application/vnd.lotus-screencam": {
		"source": SOURCE.IANA,
		"extensions": ["scm"]
	},
	"application/vnd.lotus-wordpro": {
		"source": SOURCE.IANA,
		"extensions": ["lwp"]
	},
	"application/vnd.macports.portpkg": {
		"source": SOURCE.IANA,
		"extensions": ["portpkg"]
	},
	"application/vnd.mapbox-vector-tile": {
		"source": SOURCE.IANA,
		"extensions": ["mvt"]
	},
	"application/vnd.marlin.drm.actiontoken+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.marlin.drm.conftoken+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.marlin.drm.license+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.marlin.drm.mdcf": {
		"source": SOURCE.IANA
	},
	"application/vnd.mason+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.maxar.archive.3tz+zip": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"application/vnd.maxmind.maxmind-raw_db": {
		"source": SOURCE.IANA
	},
	"application/vnd.mcd": {
		"source": SOURCE.IANA,
		"extensions": ["mcd"]
	},
	"application/vnd.medcalcdata": {
		"source": SOURCE.IANA,
		"extensions": ["mc1"]
	},
	"application/vnd.mediastation.cdkey": {
		"source": SOURCE.IANA,
		"extensions": ["cdkey"]
	},
	"application/vnd.meridian-slingshot": {
		"source": SOURCE.IANA
	},
	"application/vnd.mfer": {
		"source": SOURCE.IANA,
		"extensions": ["mwf"]
	},
	"application/vnd.mfmp": {
		"source": SOURCE.IANA,
		"extensions": ["mfm"]
	},
	"application/vnd.micro+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.micrografx.flo": {
		"source": SOURCE.IANA,
		"extensions": ["flo"]
	},
	"application/vnd.micrografx.igx": {
		"source": SOURCE.IANA,
		"extensions": ["igx"]
	},
	"application/vnd.microsoft.portable-executable": {
		"source": SOURCE.IANA
	},
	"application/vnd.microsoft.windows.thumbnail-cache": {
		"source": SOURCE.IANA
	},
	"application/vnd.miele+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.mif": {
		"source": SOURCE.IANA,
		"extensions": ["mif"]
	},
	"application/vnd.minisoft-hp3000-save": {
		"source": SOURCE.IANA
	},
	"application/vnd.mitsubishi.misty-guard.trustweb": {
		"source": SOURCE.IANA
	},
	"application/vnd.mobius.daf": {
		"source": SOURCE.IANA,
		"extensions": ["daf"]
	},
	"application/vnd.mobius.dis": {
		"source": SOURCE.IANA,
		"extensions": ["dis"]
	},
	"application/vnd.mobius.mbk": {
		"source": SOURCE.IANA,
		"extensions": ["mbk"]
	},
	"application/vnd.mobius.mqy": {
		"source": SOURCE.IANA,
		"extensions": ["mqy"]
	},
	"application/vnd.mobius.msl": {
		"source": SOURCE.IANA,
		"extensions": ["msl"]
	},
	"application/vnd.mobius.plc": {
		"source": SOURCE.IANA,
		"extensions": ["plc"]
	},
	"application/vnd.mobius.txf": {
		"source": SOURCE.IANA,
		"extensions": ["txf"]
	},
	"application/vnd.mophun.application": {
		"source": SOURCE.IANA,
		"extensions": ["mpn"]
	},
	"application/vnd.mophun.certificate": {
		"source": SOURCE.IANA,
		"extensions": ["mpc"]
	},
	"application/vnd.motorola.flexsuite": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.adsi": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.fis": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.gotap": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.kmr": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.ttc": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.flexsuite.wem": {
		"source": SOURCE.IANA
	},
	"application/vnd.motorola.iprm": {
		"source": SOURCE.IANA
	},
	"application/vnd.mozilla.xul+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xul"]
	},
	"application/vnd.ms-3mfdocument": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-artgalry": {
		"source": SOURCE.IANA,
		"extensions": ["cil"]
	},
	"application/vnd.ms-asf": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-cab-compressed": {
		"source": SOURCE.IANA,
		"extensions": ["cab"]
	},
	"application/vnd.ms-color.iccprofile": {
		"source": SOURCE.APACHE
	},
	"application/vnd.ms-excel": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["xls","xlm","xla","xlc","xlt","xlw"]
	},
	"application/vnd.ms-excel.addin.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["xlam"]
	},
	"application/vnd.ms-excel.sheet.binary.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["xlsb"]
	},
	"application/vnd.ms-excel.sheet.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["xlsm"]
	},
	"application/vnd.ms-excel.template.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["xltm"]
	},
	"application/vnd.ms-fontobject": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["eot"]
	},
	"application/vnd.ms-htmlhelp": {
		"source": SOURCE.IANA,
		"extensions": ["chm"]
	},
	"application/vnd.ms-ims": {
		"source": SOURCE.IANA,
		"extensions": ["ims"]
	},
	"application/vnd.ms-lrm": {
		"source": SOURCE.IANA,
		"extensions": ["lrm"]
	},
	"application/vnd.ms-office.activex+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ms-officetheme": {
		"source": SOURCE.IANA,
		"extensions": ["thmx"]
	},
	"application/vnd.ms-opentype": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.ms-outlook": {
		"compressible": false,
		"extensions": ["msg"]
	},
	"application/vnd.ms-package.obfuscated-opentype": {
		"source": SOURCE.APACHE
	},
	"application/vnd.ms-pki.seccat": {
		"source": SOURCE.APACHE,
		"extensions": ["cat"]
	},
	"application/vnd.ms-pki.stl": {
		"source": SOURCE.APACHE,
		"extensions": ["stl"]
	},
	"application/vnd.ms-playready.initiator+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ms-powerpoint": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["ppt","pps","pot"]
	},
	"application/vnd.ms-powerpoint.addin.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["ppam"]
	},
	"application/vnd.ms-powerpoint.presentation.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["pptm"]
	},
	"application/vnd.ms-powerpoint.slide.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["sldm"]
	},
	"application/vnd.ms-powerpoint.slideshow.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["ppsm"]
	},
	"application/vnd.ms-powerpoint.template.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["potm"]
	},
	"application/vnd.ms-printdevicecapabilities+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ms-printing.printticket+xml": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.ms-printschematicket+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ms-project": {
		"source": SOURCE.IANA,
		"extensions": ["mpp","mpt"]
	},
	"application/vnd.ms-tnef": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-windows.devicepairing": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-windows.nwprinting.oob": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-windows.printerpairing": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-windows.wsd.oob": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-wmdrm.lic-chlg-req": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-wmdrm.lic-resp": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-wmdrm.meter-chlg-req": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-wmdrm.meter-resp": {
		"source": SOURCE.IANA
	},
	"application/vnd.ms-word.document.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["docm"]
	},
	"application/vnd.ms-word.template.macroenabled.12": {
		"source": SOURCE.IANA,
		"extensions": ["dotm"]
	},
	"application/vnd.ms-works": {
		"source": SOURCE.IANA,
		"extensions": ["wps","wks","wcm","wraw_db"]
	},
	"application/vnd.ms-wpl": {
		"source": SOURCE.IANA,
		"extensions": ["wpl"]
	},
	"application/vnd.ms-xpsdocument": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["xps"]
	},
	"application/vnd.msa-disk-image": {
		"source": SOURCE.IANA
	},
	"application/vnd.mseq": {
		"source": SOURCE.IANA,
		"extensions": ["mseq"]
	},
	"application/vnd.msign": {
		"source": SOURCE.IANA
	},
	"application/vnd.multiad.creator": {
		"source": SOURCE.IANA
	},
	"application/vnd.multiad.creator.cif": {
		"source": SOURCE.IANA
	},
	"application/vnd.music-niff": {
		"source": SOURCE.IANA
	},
	"application/vnd.musician": {
		"source": SOURCE.IANA,
		"extensions": ["mus"]
	},
	"application/vnd.muvee.style": {
		"source": SOURCE.IANA,
		"extensions": ["msty"]
	},
	"application/vnd.mynfc": {
		"source": SOURCE.IANA,
		"extensions": ["taglet"]
	},
	"application/vnd.nacamar.ybrid+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.ncd.control": {
		"source": SOURCE.IANA
	},
	"application/vnd.ncd.reference": {
		"source": SOURCE.IANA
	},
	"application/vnd.nearst.inv+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nebumind.line": {
		"source": SOURCE.IANA
	},
	"application/vnd.nervana": {
		"source": SOURCE.IANA
	},
	"application/vnd.netfpx": {
		"source": SOURCE.IANA
	},
	"application/vnd.neurolanguage.nlu": {
		"source": SOURCE.IANA,
		"extensions": ["nlu"]
	},
	"application/vnd.nimn": {
		"source": SOURCE.IANA
	},
	"application/vnd.nintendo.nitro.rom": {
		"source": SOURCE.IANA
	},
	"application/vnd.nintendo.snes.rom": {
		"source": SOURCE.IANA
	},
	"application/vnd.nitf": {
		"source": SOURCE.IANA,
		"extensions": ["ntf","nitf"]
	},
	"application/vnd.noblenet-directory": {
		"source": SOURCE.IANA,
		"extensions": ["nnd"]
	},
	"application/vnd.noblenet-sealer": {
		"source": SOURCE.IANA,
		"extensions": ["nns"]
	},
	"application/vnd.noblenet-web": {
		"source": SOURCE.IANA,
		"extensions": ["nnw"]
	},
	"application/vnd.nokia.catalogs": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.conml+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.conml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nokia.iptv.config+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nokia.isds-radio-presets": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.landmark+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.landmark+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nokia.landmarkcollection+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nokia.n-gage.ac+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ac"]
	},
	"application/vnd.nokia.n-gage.data": {
		"source": SOURCE.IANA,
		"extensions": ["ngdat"]
	},
	"application/vnd.nokia.n-gage.symbian.install": {
		"source": SOURCE.APACHE,
		"extensions": ["n-gage"]
	},
	"application/vnd.nokia.ncd": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.pcd+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.nokia.pcd+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.nokia.radio-preset": {
		"source": SOURCE.IANA,
		"extensions": ["rpst"]
	},
	"application/vnd.nokia.radio-presets": {
		"source": SOURCE.IANA,
		"extensions": ["rpss"]
	},
	"application/vnd.novadigm.edm": {
		"source": SOURCE.IANA,
		"extensions": ["edm"]
	},
	"application/vnd.novadigm.edx": {
		"source": SOURCE.IANA,
		"extensions": ["edx"]
	},
	"application/vnd.novadigm.ext": {
		"source": SOURCE.IANA,
		"extensions": ["ext"]
	},
	"application/vnd.ntt-local.content-share": {
		"source": SOURCE.IANA
	},
	"application/vnd.ntt-local.file-transfer": {
		"source": SOURCE.IANA
	},
	"application/vnd.ntt-local.ogw_remote-access": {
		"source": SOURCE.IANA
	},
	"application/vnd.ntt-local.sip-ta_remote": {
		"source": SOURCE.IANA
	},
	"application/vnd.ntt-local.sip-ta_tcp_stream": {
		"source": SOURCE.IANA
	},
	"application/vnd.oasis.opendocument.chart": {
		"source": SOURCE.IANA,
		"extensions": ["odc"]
	},
	"application/vnd.oasis.opendocument.chart-template": {
		"source": SOURCE.IANA,
		"extensions": ["otc"]
	},
	"application/vnd.oasis.opendocument.database": {
		"source": SOURCE.IANA,
		"extensions": ["oraw_db"]
	},
	"application/vnd.oasis.opendocument.formula": {
		"source": SOURCE.IANA,
		"extensions": ["odf"]
	},
	"application/vnd.oasis.opendocument.formula-template": {
		"source": SOURCE.IANA,
		"extensions": ["odft"]
	},
	"application/vnd.oasis.opendocument.graphics": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["odg"]
	},
	"application/vnd.oasis.opendocument.graphics-template": {
		"source": SOURCE.IANA,
		"extensions": ["otg"]
	},
	"application/vnd.oasis.opendocument.image": {
		"source": SOURCE.IANA,
		"extensions": ["odi"]
	},
	"application/vnd.oasis.opendocument.image-template": {
		"source": SOURCE.IANA,
		"extensions": ["oti"]
	},
	"application/vnd.oasis.opendocument.presentation": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["odp"]
	},
	"application/vnd.oasis.opendocument.presentation-template": {
		"source": SOURCE.IANA,
		"extensions": ["otp"]
	},
	"application/vnd.oasis.opendocument.spreadsheet": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["ods"]
	},
	"application/vnd.oasis.opendocument.spreadsheet-template": {
		"source": SOURCE.IANA,
		"extensions": ["ots"]
	},
	"application/vnd.oasis.opendocument.text": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["odt"]
	},
	"application/vnd.oasis.opendocument.text-master": {
		"source": SOURCE.IANA,
		"extensions": ["odm"]
	},
	"application/vnd.oasis.opendocument.text-template": {
		"source": SOURCE.IANA,
		"extensions": ["ott"]
	},
	"application/vnd.oasis.opendocument.text-web": {
		"source": SOURCE.IANA,
		"extensions": ["oth"]
	},
	"application/vnd.obn": {
		"source": SOURCE.IANA
	},
	"application/vnd.ocf+cbor": {
		"source": SOURCE.IANA
	},
	"application/vnd.oci.image.manifest.v1+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oftn.l10n+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.contentaccessdownload+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.contentaccessstreaming+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.cspg-hexbinary": {
		"source": SOURCE.IANA
	},
	"application/vnd.oipf.dae.svg+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.dae.xhtml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.mippvcontrolmessage+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.pae.gem": {
		"source": SOURCE.IANA
	},
	"application/vnd.oipf.spdiscovery+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.spdlist+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.ueprofile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oipf.userprofile+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.olpc-sugar": {
		"source": SOURCE.IANA,
		"extensions": ["xo"]
	},
	"application/vnd.oma-scws-config": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma-scws-http-request": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma-scws-http-response": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.associated-procedure-parameter+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.bcast.drm-trigger+xml": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.oma.bcast.imd+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.bcast.ltkm": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.notification+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.bcast.provisioningtrigger": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.sgboot": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.sgdd+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.bcast.sgdu": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.simple-symbol-container": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.bcast.smartcard-trigger+xml": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/vnd.oma.bcast.sprov+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.bcast.stkm": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.cab-address-book+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.cab-feature-handler+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.cab-pcc+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.cab-subs-invite+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.cab-user-prefs+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.dcd": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.dcdc": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.dd2+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["dd2"]
	},
	"application/vnd.oma.drm.risd+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.group-usage-list+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.lwm2m+cbor": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.lwm2m+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.lwm2m+tlv": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.pal+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.poc.detailed-progress-report+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.poc.final-report+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.poc.groups+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.poc.invocation-descriptor+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.poc.optimized-progress-report+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.push": {
		"source": SOURCE.IANA
	},
	"application/vnd.oma.scidm.messages+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oma.xcap-directory+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.omads-email+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/vnd.omads-file+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/vnd.omads-folder+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/vnd.omaloc-supl-init": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepager": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepagertamp": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepagertamx": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepagertat": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepagertatp": {
		"source": SOURCE.IANA
	},
	"application/vnd.onepagertatx": {
		"source": SOURCE.IANA
	},
	"application/vnd.onvif.metadata": {
		"source": SOURCE.IANA
	},
	"application/vnd.openblox.game+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["obgx"]
	},
	"application/vnd.openblox.game-binary": {
		"source": SOURCE.IANA
	},
	"application/vnd.openeye.oeb": {
		"source": SOURCE.IANA
	},
	"application/vnd.openofficeorg.extension": {
		"source": SOURCE.APACHE,
		"extensions": ["oxt"]
	},
	"application/vnd.openstreetmap.data+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["osm"]
	},
	"application/vnd.opentimestamps.ots": {
		"source": SOURCE.IANA
	},
	"application/vnd.openxmlformats-officedocument.custom-properties+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.customxmlproperties+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawing+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.chart+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.chartshapes+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.diagramcolors+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.diagramdata+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.diagramlayout+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.drawingml.diagramstyle+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.extended-properties+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.commentauthors+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.comments+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.handoutmaster+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.notesmaster+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.notesslide+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.presentation": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["pptx"]
	},
	"application/vnd.openxmlformats-officedocument.presentationml.presentation.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.presprops+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slide": {
		"source": SOURCE.IANA,
		"extensions": ["sldx"]
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slide+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slidelayout+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slidemaster+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slideshow": {
		"source": SOURCE.IANA,
		"extensions": ["ppsx"]
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slideshow.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.slideupdateinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.tablestyles+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.tags+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.template": {
		"source": SOURCE.IANA,
		"extensions": ["potx"]
	},
	"application/vnd.openxmlformats-officedocument.presentationml.template.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.presentationml.viewprops+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.calcchain+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.chartsheet+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.comments+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.connections+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.dialogsheet+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.externallink+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.pivotcachedefinition+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.pivotcacherecords+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.pivottable+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.querytable+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.revisionheaders+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.revisionlog+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.sharedstrings+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["xlsx"]
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.sheet.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.sheetmetadata+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.styles+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.table+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.tablesinglecells+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.template": {
		"source": SOURCE.IANA,
		"extensions": ["xltx"]
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.template.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.usernames+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.volatiledependencies+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.spreadsheetml.worksheet+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.theme+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.themeoverride+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.vmldrawing": {
		"source": SOURCE.IANA
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.comments+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.document": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["docx"]
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.document.glossary+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.endnotes+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.fonttable+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.footer+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.footnotes+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.numbering+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.settings+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.template": {
		"source": SOURCE.IANA,
		"extensions": ["dotx"]
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.template.main+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-officedocument.wordprocessingml.websettings+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-package.core-properties+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-package.digital-signature-xmlsignature+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.openxmlformats-package.relationships+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oracle.resource+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.orange.indata": {
		"source": SOURCE.IANA
	},
	"application/vnd.osa.netdeploy": {
		"source": SOURCE.IANA
	},
	"application/vnd.osgeo.mapguide.package": {
		"source": SOURCE.IANA,
		"extensions": ["mgp"]
	},
	"application/vnd.osgi.bundle": {
		"source": SOURCE.IANA
	},
	"application/vnd.osgi.dp": {
		"source": SOURCE.IANA,
		"extensions": ["dp"]
	},
	"application/vnd.osgi.subsystem": {
		"source": SOURCE.IANA,
		"extensions": ["esa"]
	},
	"application/vnd.otps.ct-kip+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.oxli.countgraph": {
		"source": SOURCE.IANA
	},
	"application/vnd.pagerduty+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.palm": {
		"source": SOURCE.IANA,
		"extensions": ["praw_db","pqa","oprc"]
	},
	"application/vnd.panoply": {
		"source": SOURCE.IANA
	},
	"application/vnd.paos.xml": {
		"source": SOURCE.IANA
	},
	"application/vnd.patentdive": {
		"source": SOURCE.IANA
	},
	"application/vnd.patientecommsdoc": {
		"source": SOURCE.IANA
	},
	"application/vnd.pawaafile": {
		"source": SOURCE.IANA,
		"extensions": ["paw"]
	},
	"application/vnd.pcos": {
		"source": SOURCE.IANA
	},
	"application/vnd.pg.format": {
		"source": SOURCE.IANA,
		"extensions": ["str"]
	},
	"application/vnd.pg.osasli": {
		"source": SOURCE.IANA,
		"extensions": ["ei6"]
	},
	"application/vnd.piaccess.application-licence": {
		"source": SOURCE.IANA
	},
	"application/vnd.picsel": {
		"source": SOURCE.IANA,
		"extensions": ["efif"]
	},
	"application/vnd.pmi.widget": {
		"source": SOURCE.IANA,
		"extensions": ["wg"]
	},
	"application/vnd.poc.group-advertisement+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.pocketlearn": {
		"source": SOURCE.IANA,
		"extensions": ["plf"]
	},
	"application/vnd.powerbuilder6": {
		"source": SOURCE.IANA,
		"extensions": ["pbd"]
	},
	"application/vnd.powerbuilder6-s": {
		"source": SOURCE.IANA
	},
	"application/vnd.powerbuilder7": {
		"source": SOURCE.IANA
	},
	"application/vnd.powerbuilder7-s": {
		"source": SOURCE.IANA
	},
	"application/vnd.powerbuilder75": {
		"source": SOURCE.IANA
	},
	"application/vnd.powerbuilder75-s": {
		"source": SOURCE.IANA
	},
	"application/vnd.preminet": {
		"source": SOURCE.IANA
	},
	"application/vnd.previewsystems.box": {
		"source": SOURCE.IANA,
		"extensions": ["box"]
	},
	"application/vnd.proteus.magazine": {
		"source": SOURCE.IANA,
		"extensions": ["mgz"]
	},
	"application/vnd.psfs": {
		"source": SOURCE.IANA
	},
	"application/vnd.publishare-delta-tree": {
		"source": SOURCE.IANA,
		"extensions": ["qps"]
	},
	"application/vnd.pvi.ptid1": {
		"source": SOURCE.IANA,
		"extensions": ["ptid"]
	},
	"application/vnd.pwg-multiplexed": {
		"source": SOURCE.IANA
	},
	"application/vnd.pwg-xhtml-print+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xhtm"]
	},
	"application/vnd.qualcomm.brew-app-res": {
		"source": SOURCE.IANA
	},
	"application/vnd.quarantainenet": {
		"source": SOURCE.IANA
	},
	"application/vnd.quark.quarkxpress": {
		"source": SOURCE.IANA,
		"extensions": ["qxd","qxt","qwd","qwt","qxl","qxb"]
	},
	"application/vnd.quobject-quoxdocument": {
		"source": SOURCE.IANA
	},
	"application/vnd.radisys.moml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-audit+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-audit-conf+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-audit-conn+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-audit-dialog+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-audit-stream+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-conf+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-base+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-fax-detect+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-fax-sendrecv+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-group+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-speech+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.radisys.msml-dialog-transform+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.rainstor.data": {
		"source": SOURCE.IANA
	},
	"application/vnd.rapid": {
		"source": SOURCE.IANA
	},
	"application/vnd.rar": {
		"source": SOURCE.IANA,
		"extensions": ["rar"]
	},
	"application/vnd.realvnc.bed": {
		"source": SOURCE.IANA,
		"extensions": ["bed"]
	},
	"application/vnd.recordare.musicxml": {
		"source": SOURCE.IANA,
		"extensions": ["mxl"]
	},
	"application/vnd.recordare.musicxml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["musicxml"]
	},
	"application/vnd.renlearn.rlprint": {
		"source": SOURCE.IANA
	},
	"application/vnd.resilient.logic": {
		"source": SOURCE.IANA
	},
	"application/vnd.restful+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.rig.cryptonote": {
		"source": SOURCE.IANA,
		"extensions": ["cryptonote"]
	},
	"application/vnd.rim.cod": {
		"source": SOURCE.APACHE,
		"extensions": ["cod"]
	},
	"application/vnd.rn-realmedia": {
		"source": SOURCE.APACHE,
		"extensions": ["rm"]
	},
	"application/vnd.rn-realmedia-vbr": {
		"source": SOURCE.APACHE,
		"extensions": ["rmvb"]
	},
	"application/vnd.route66.link66+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["link66"]
	},
	"application/vnd.rs-274x": {
		"source": SOURCE.IANA
	},
	"application/vnd.ruckus.download": {
		"source": SOURCE.IANA
	},
	"application/vnd.s3sms": {
		"source": SOURCE.IANA
	},
	"application/vnd.sailingtracker.track": {
		"source": SOURCE.IANA,
		"extensions": ["st"]
	},
	"application/vnd.sar": {
		"source": SOURCE.IANA
	},
	"application/vnd.sbm.cid": {
		"source": SOURCE.IANA
	},
	"application/vnd.sbm.mid2": {
		"source": SOURCE.IANA
	},
	"application/vnd.scribus": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.3df": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.csf": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.doc": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.eml": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.mht": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.net": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.ppt": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.tiff": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealed.xls": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealedmedia.softseal.html": {
		"source": SOURCE.IANA
	},
	"application/vnd.sealedmedia.softseal.pdf": {
		"source": SOURCE.IANA
	},
	"application/vnd.seemail": {
		"source": SOURCE.IANA,
		"extensions": ["see"]
	},
	"application/vnd.seis+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.sema": {
		"source": SOURCE.IANA,
		"extensions": ["sema"]
	},
	"application/vnd.semd": {
		"source": SOURCE.IANA,
		"extensions": ["semd"]
	},
	"application/vnd.semf": {
		"source": SOURCE.IANA,
		"extensions": ["semf"]
	},
	"application/vnd.shade-save-file": {
		"source": SOURCE.IANA
	},
	"application/vnd.shana.informed.formdata": {
		"source": SOURCE.IANA,
		"extensions": ["ifm"]
	},
	"application/vnd.shana.informed.formtemplate": {
		"source": SOURCE.IANA,
		"extensions": ["itp"]
	},
	"application/vnd.shana.informed.interchange": {
		"source": SOURCE.IANA,
		"extensions": ["iif"]
	},
	"application/vnd.shana.informed.package": {
		"source": SOURCE.IANA,
		"extensions": ["ipk"]
	},
	"application/vnd.shootproof+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.shopkick+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.shp": {
		"source": SOURCE.IANA
	},
	"application/vnd.shx": {
		"source": SOURCE.IANA
	},
	"application/vnd.sigrok.session": {
		"source": SOURCE.IANA
	},
	"application/vnd.simtech-mindmapper": {
		"source": SOURCE.IANA,
		"extensions": ["twd","twds"]
	},
	"application/vnd.siren+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.smaf": {
		"source": SOURCE.IANA,
		"extensions": ["mmf"]
	},
	"application/vnd.smart.notebook": {
		"source": SOURCE.IANA
	},
	"application/vnd.smart.teacher": {
		"source": SOURCE.IANA,
		"extensions": ["teacher"]
	},
	"application/vnd.snesdev-page-table": {
		"source": SOURCE.IANA
	},
	"application/vnd.software602.filler.form+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["fo"]
	},
	"application/vnd.software602.filler.form-xml-zip": {
		"source": SOURCE.IANA
	},
	"application/vnd.solent.sdkm+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["sdkm","sdkd"]
	},
	"application/vnd.spotfire.dxp": {
		"source": SOURCE.IANA,
		"extensions": ["dxp"]
	},
	"application/vnd.spotfire.sfs": {
		"source": SOURCE.IANA,
		"extensions": ["sfs"]
	},
	"application/vnd.sqlite3": {
		"source": SOURCE.IANA
	},
	"application/vnd.sss-cod": {
		"source": SOURCE.IANA
	},
	"application/vnd.sss-dtf": {
		"source": SOURCE.IANA
	},
	"application/vnd.sss-ntf": {
		"source": SOURCE.IANA
	},
	"application/vnd.stardivision.calc": {
		"source": SOURCE.APACHE,
		"extensions": ["sdc"]
	},
	"application/vnd.stardivision.draw": {
		"source": SOURCE.APACHE,
		"extensions": ["sda"]
	},
	"application/vnd.stardivision.impress": {
		"source": SOURCE.APACHE,
		"extensions": ["sdd"]
	},
	"application/vnd.stardivision.math": {
		"source": SOURCE.APACHE,
		"extensions": ["smf"]
	},
	"application/vnd.stardivision.writer": {
		"source": SOURCE.APACHE,
		"extensions": ["sdw","vor"]
	},
	"application/vnd.stardivision.writer-global": {
		"source": SOURCE.APACHE,
		"extensions": ["sgl"]
	},
	"application/vnd.stepmania.package": {
		"source": SOURCE.IANA,
		"extensions": ["smzip"]
	},
	"application/vnd.stepmania.stepchart": {
		"source": SOURCE.IANA,
		"extensions": ["sm"]
	},
	"application/vnd.street-stream": {
		"source": SOURCE.IANA
	},
	"application/vnd.sun.wadl+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wadl"]
	},
	"application/vnd.sun.xml.calc": {
		"source": SOURCE.APACHE,
		"extensions": ["sxc"]
	},
	"application/vnd.sun.xml.calc.template": {
		"source": SOURCE.APACHE,
		"extensions": ["stc"]
	},
	"application/vnd.sun.xml.draw": {
		"source": SOURCE.APACHE,
		"extensions": ["sxd"]
	},
	"application/vnd.sun.xml.draw.template": {
		"source": SOURCE.APACHE,
		"extensions": ["std"]
	},
	"application/vnd.sun.xml.impress": {
		"source": SOURCE.APACHE,
		"extensions": ["sxi"]
	},
	"application/vnd.sun.xml.impress.template": {
		"source": SOURCE.APACHE,
		"extensions": ["sti"]
	},
	"application/vnd.sun.xml.math": {
		"source": SOURCE.APACHE,
		"extensions": ["sxm"]
	},
	"application/vnd.sun.xml.writer": {
		"source": SOURCE.APACHE,
		"extensions": ["sxw"]
	},
	"application/vnd.sun.xml.writer.global": {
		"source": SOURCE.APACHE,
		"extensions": ["sxg"]
	},
	"application/vnd.sun.xml.writer.template": {
		"source": SOURCE.APACHE,
		"extensions": ["stw"]
	},
	"application/vnd.sus-calendar": {
		"source": SOURCE.IANA,
		"extensions": ["sus","susp"]
	},
	"application/vnd.svd": {
		"source": SOURCE.IANA,
		"extensions": ["svd"]
	},
	"application/vnd.swiftview-ics": {
		"source": SOURCE.IANA
	},
	"application/vnd.sycle+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.syft+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.symbian.install": {
		"source": SOURCE.APACHE,
		"extensions": ["sis","sisx"]
	},
	"application/vnd.syncml+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["xsm"]
	},
	"application/vnd.syncml.dm+wbxml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"extensions": ["bdm"]
	},
	"application/vnd.syncml.dm+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["xdm"]
	},
	"application/vnd.syncml.dm.notification": {
		"source": SOURCE.IANA
	},
	"application/vnd.syncml.dmddf+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.syncml.dmddf+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["ddf"]
	},
	"application/vnd.syncml.dmtnds+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.syncml.dmtnds+xml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true
	},
	"application/vnd.syncml.ds.notification": {
		"source": SOURCE.IANA
	},
	"application/vnd.tableschema+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.tao.intent-module-archive": {
		"source": SOURCE.IANA,
		"extensions": ["tao"]
	},
	"application/vnd.tcpdump.pcap": {
		"source": SOURCE.IANA,
		"extensions": ["pcap","cap","dmp"]
	},
	"application/vnd.think-cell.ppttc+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.tmd.mediaflex.api+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.tml": {
		"source": SOURCE.IANA
	},
	"application/vnd.tmobile-livetv": {
		"source": SOURCE.IANA,
		"extensions": ["tmo"]
	},
	"application/vnd.tri.onesource": {
		"source": SOURCE.IANA
	},
	"application/vnd.trid.tpt": {
		"source": SOURCE.IANA,
		"extensions": ["tpt"]
	},
	"application/vnd.triscape.mxs": {
		"source": SOURCE.IANA,
		"extensions": ["mxs"]
	},
	"application/vnd.trueapp": {
		"source": SOURCE.IANA,
		"extensions": ["tra"]
	},
	"application/vnd.truedoc": {
		"source": SOURCE.IANA
	},
	"application/vnd.ubisoft.webplayer": {
		"source": SOURCE.IANA
	},
	"application/vnd.ufdl": {
		"source": SOURCE.IANA,
		"extensions": ["ufd","ufdl"]
	},
	"application/vnd.uiq.theme": {
		"source": SOURCE.IANA,
		"extensions": ["utz"]
	},
	"application/vnd.umajin": {
		"source": SOURCE.IANA,
		"extensions": ["umj"]
	},
	"application/vnd.unity": {
		"source": SOURCE.IANA,
		"extensions": ["unityweb"]
	},
	"application/vnd.uoml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["uoml","uo"]
	},
	"application/vnd.uplanet.alert": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.alert-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.bearer-choice": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.bearer-choice-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.cacheop": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.cacheop-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.channel": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.channel-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.list": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.list-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.listcmd": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.listcmd-wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.uplanet.signal": {
		"source": SOURCE.IANA
	},
	"application/vnd.uri-map": {
		"source": SOURCE.IANA
	},
	"application/vnd.valve.source.material": {
		"source": SOURCE.IANA
	},
	"application/vnd.vcx": {
		"source": SOURCE.IANA,
		"extensions": ["vcx"]
	},
	"application/vnd.vd-study": {
		"source": SOURCE.IANA
	},
	"application/vnd.vectorworks": {
		"source": SOURCE.IANA
	},
	"application/vnd.vel+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.verimatrix.vcas": {
		"source": SOURCE.IANA
	},
	"application/vnd.veritone.aion+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.veryant.thin": {
		"source": SOURCE.IANA
	},
	"application/vnd.ves.encrypted": {
		"source": SOURCE.IANA
	},
	"application/vnd.vidsoft.vidconference": {
		"source": SOURCE.IANA
	},
	"application/vnd.visio": {
		"source": SOURCE.IANA,
		"extensions": ["vsd","vst","vss","vsw"]
	},
	"application/vnd.visionary": {
		"source": SOURCE.IANA,
		"extensions": ["vis"]
	},
	"application/vnd.vividence.scriptfile": {
		"source": SOURCE.IANA
	},
	"application/vnd.vsf": {
		"source": SOURCE.IANA,
		"extensions": ["vsf"]
	},
	"application/vnd.wap.sic": {
		"source": SOURCE.IANA
	},
	"application/vnd.wap.slc": {
		"source": SOURCE.IANA
	},
	"application/vnd.wap.wbxml": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"extensions": ["wbxml"]
	},
	"application/vnd.wap.wmlc": {
		"source": SOURCE.IANA,
		"extensions": ["wmlc"]
	},
	"application/vnd.wap.wmlscriptc": {
		"source": SOURCE.IANA,
		"extensions": ["wmlsc"]
	},
	"application/vnd.webturbo": {
		"source": SOURCE.IANA,
		"extensions": ["wtb"]
	},
	"application/vnd.wfa.dpp": {
		"source": SOURCE.IANA
	},
	"application/vnd.wfa.p2p": {
		"source": SOURCE.IANA
	},
	"application/vnd.wfa.wsc": {
		"source": SOURCE.IANA
	},
	"application/vnd.windows.devicepairing": {
		"source": SOURCE.IANA
	},
	"application/vnd.wmc": {
		"source": SOURCE.IANA
	},
	"application/vnd.wmf.bootstrap": {
		"source": SOURCE.IANA
	},
	"application/vnd.wolfram.mathematica": {
		"source": SOURCE.IANA
	},
	"application/vnd.wolfram.mathematica.package": {
		"source": SOURCE.IANA
	},
	"application/vnd.wolfram.player": {
		"source": SOURCE.IANA,
		"extensions": ["nbp"]
	},
	"application/vnd.wordperfect": {
		"source": SOURCE.IANA,
		"extensions": ["wpd"]
	},
	"application/vnd.wqd": {
		"source": SOURCE.IANA,
		"extensions": ["wqd"]
	},
	"application/vnd.wrq-hp3000-labelled": {
		"source": SOURCE.IANA
	},
	"application/vnd.wt.stf": {
		"source": SOURCE.IANA,
		"extensions": ["stf"]
	},
	"application/vnd.wv.csp+wbxml": {
		"source": SOURCE.IANA
	},
	"application/vnd.wv.csp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.wv.ssp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.xacml+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.xara": {
		"source": SOURCE.IANA,
		"extensions": ["xar"]
	},
	"application/vnd.xfdl": {
		"source": SOURCE.IANA,
		"extensions": ["xfdl"]
	},
	"application/vnd.xfdl.webform": {
		"source": SOURCE.IANA
	},
	"application/vnd.xmi+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vnd.xmpie.cpkg": {
		"source": SOURCE.IANA
	},
	"application/vnd.xmpie.dpkg": {
		"source": SOURCE.IANA
	},
	"application/vnd.xmpie.plan": {
		"source": SOURCE.IANA
	},
	"application/vnd.xmpie.ppkg": {
		"source": SOURCE.IANA
	},
	"application/vnd.xmpie.xlim": {
		"source": SOURCE.IANA
	},
	"application/vnd.yamaha.hv-dic": {
		"source": SOURCE.IANA,
		"extensions": ["hvd"]
	},
	"application/vnd.yamaha.hv-script": {
		"source": SOURCE.IANA,
		"extensions": ["hvs"]
	},
	"application/vnd.yamaha.hv-voice": {
		"source": SOURCE.IANA,
		"extensions": ["hvp"]
	},
	"application/vnd.yamaha.openscoreformat": {
		"source": SOURCE.IANA,
		"extensions": ["osf"]
	},
	"application/vnd.yamaha.openscoreformat.osfpvg+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["osfpvg"]
	},
	"application/vnd.yamaha.remote-setup": {
		"source": SOURCE.IANA
	},
	"application/vnd.yamaha.smaf-audio": {
		"source": SOURCE.IANA,
		"extensions": ["saf"]
	},
	"application/vnd.yamaha.smaf-phrase": {
		"source": SOURCE.IANA,
		"extensions": ["spf"]
	},
	"application/vnd.yamaha.through-ngn": {
		"source": SOURCE.IANA
	},
	"application/vnd.yamaha.tunnel-udpencap": {
		"source": SOURCE.IANA
	},
	"application/vnd.yaoweme": {
		"source": SOURCE.IANA
	},
	"application/vnd.yellowriver-custom-menu": {
		"source": SOURCE.IANA,
		"extensions": ["cmp"]
	},
	"application/vnd.zul": {
		"source": SOURCE.IANA,
		"extensions": ["zir","zirz"]
	},
	"application/vnd.zzazz.deck+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["zaz"]
	},
	"application/voicexml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["vxml"]
	},
	"application/voucher-cms+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/vq-rtcpxr": {
		"source": SOURCE.IANA
	},
	"application/wasm": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wasm"]
	},
	"application/watcherinfo+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wif"]
	},
	"application/webpush-options+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/whoispp-query": {
		"source": SOURCE.IANA
	},
	"application/whoispp-response": {
		"source": SOURCE.IANA
	},
	"application/widget": {
		"source": SOURCE.IANA,
		"extensions": ["wgt"]
	},
	"application/winhlp": {
		"source": SOURCE.APACHE,
		"extensions": ["hlp"]
	},
	"application/wita": {
		"source": SOURCE.IANA
	},
	"application/wordperfect5.1": {
		"source": SOURCE.IANA
	},
	"application/wsdl+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wsdl"]
	},
	"application/wspolicy+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["wspolicy"]
	},
	"application/x-7z-compressed": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["7z"]
	},
	"application/x-abiword": {
		"source": SOURCE.APACHE,
		"extensions": ["abw"]
	},
	"application/x-ace-compressed": {
		"source": SOURCE.APACHE,
		"extensions": ["ace"]
	},
	"application/x-amf": {
		"source": SOURCE.APACHE
	},
	"application/x-apple-diskimage": {
		"source": SOURCE.APACHE,
		"extensions": ["dmg"]
	},
	"application/x-arj": {
		"compressible": false,
		"extensions": ["arj"]
	},
	"application/x-authorware-bin": {
		"source": SOURCE.APACHE,
		"extensions": ["aab","x32","u32","vox"]
	},
	"application/x-authorware-map": {
		"source": SOURCE.APACHE,
		"extensions": ["aam"]
	},
	"application/x-authorware-seg": {
		"source": SOURCE.APACHE,
		"extensions": ["aas"]
	},
	"application/x-bcpio": {
		"source": SOURCE.APACHE,
		"extensions": ["bcpio"]
	},
	"application/x-bdoc": {
		"compressible": false,
		"extensions": ["bdoc"]
	},
	"application/x-bittorrent": {
		"source": SOURCE.APACHE,
		"extensions": ["torrent"]
	},
	"application/x-blorb": {
		"source": SOURCE.APACHE,
		"extensions": ["blb","blorb"]
	},
	"application/x-bzip": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["bz"]
	},
	"application/x-bzip2": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["bz2","boz"]
	},
	"application/x-cbr": {
		"source": SOURCE.APACHE,
		"extensions": ["cbr","cba","cbt","cbz","cb7"]
	},
	"application/x-cdlink": {
		"source": SOURCE.APACHE,
		"extensions": ["vcd"]
	},
	"application/x-cfs-compressed": {
		"source": SOURCE.APACHE,
		"extensions": ["cfs"]
	},
	"application/x-chat": {
		"source": SOURCE.APACHE,
		"extensions": ["chat"]
	},
	"application/x-chess-pgn": {
		"source": SOURCE.APACHE,
		"extensions": ["pgn"]
	},
	"application/x-chrome-extension": {
		"extensions": ["crx"]
	},
	"application/x-cocoa": {
		"source": SOURCE.NGINX,
		"extensions": ["cco"]
	},
	"application/x-compress": {
		"source": SOURCE.APACHE
	},
	"application/x-conference": {
		"source": SOURCE.APACHE,
		"extensions": ["nsc"]
	},
	"application/x-cpio": {
		"source": SOURCE.APACHE,
		"extensions": ["cpio"]
	},
	"application/x-csh": {
		"source": SOURCE.APACHE,
		"extensions": ["csh"]
	},
	"application/x-deb": {
		"compressible": false
	},
	"application/x-debian-package": {
		"source": SOURCE.APACHE,
		"extensions": ["deb","udeb"]
	},
	"application/x-dgc-compressed": {
		"source": SOURCE.APACHE,
		"extensions": ["dgc"]
	},
	"application/x-director": {
		"source": SOURCE.APACHE,
		"extensions": ["dir","dcr","dxr","cst","cct","cxt","w3d","fgd","swa"]
	},
	"application/x-doom": {
		"source": SOURCE.APACHE,
		"extensions": ["wad"]
	},
	"application/x-dtbncx+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["ncx"]
	},
	"application/x-dtbook+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["dtb"]
	},
	"application/x-dtbresource+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["res"]
	},
	"application/x-dvi": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["dvi"]
	},
	"application/x-envoy": {
		"source": SOURCE.APACHE,
		"extensions": ["evy"]
	},
	"application/x-eva": {
		"source": SOURCE.APACHE,
		"extensions": ["eva"]
	},
	"application/x-font-bdf": {
		"source": SOURCE.APACHE,
		"extensions": ["bdf"]
	},
	"application/x-font-dos": {
		"source": SOURCE.APACHE
	},
	"application/x-font-framemaker": {
		"source": SOURCE.APACHE
	},
	"application/x-font-ghostscript": {
		"source": SOURCE.APACHE,
		"extensions": ["gsf"]
	},
	"application/x-font-libgrx": {
		"source": SOURCE.APACHE
	},
	"application/x-font-linux-psf": {
		"source": SOURCE.APACHE,
		"extensions": ["psf"]
	},
	"application/x-font-pcf": {
		"source": SOURCE.APACHE,
		"extensions": ["pcf"]
	},
	"application/x-font-snf": {
		"source": SOURCE.APACHE,
		"extensions": ["snf"]
	},
	"application/x-font-speedo": {
		"source": SOURCE.APACHE
	},
	"application/x-font-sunos-news": {
		"source": SOURCE.APACHE
	},
	"application/x-font-type1": {
		"source": SOURCE.APACHE,
		"extensions": ["pfa","pfb","pfm","afm"]
	},
	"application/x-font-vfont": {
		"source": SOURCE.APACHE
	},
	"application/x-freearc": {
		"source": SOURCE.APACHE,
		"extensions": ["arc"]
	},
	"application/x-futuresplash": {
		"source": SOURCE.APACHE,
		"extensions": ["spl"]
	},
	"application/x-gca-compressed": {
		"source": SOURCE.APACHE,
		"extensions": ["gca"]
	},
	"application/x-glulx": {
		"source": SOURCE.APACHE,
		"extensions": ["ulx"]
	},
	"application/x-gnumeric": {
		"source": SOURCE.APACHE,
		"extensions": ["gnumeric"]
	},
	"application/x-gramps-xml": {
		"source": SOURCE.APACHE,
		"extensions": ["gramps"]
	},
	"application/x-gtar": {
		"source": SOURCE.APACHE,
		"extensions": ["gtar"]
	},
	"application/x-gzip": {
		"source": SOURCE.APACHE
	},
	"application/x-hdf": {
		"source": SOURCE.APACHE,
		"extensions": ["hdf"]
	},
	"application/x-httpd-php": {
		"compressible": true,
		"extensions": ["php"]
	},
	"application/x-install-instructions": {
		"source": SOURCE.APACHE,
		"extensions": ["install"]
	},
	"application/x-iso9660-image": {
		"source": SOURCE.APACHE,
		"extensions": ["iso"]
	},
	"application/x-iwork-keynote-sffkey": {
		"extensions": ["key"]
	},
	"application/x-iwork-numbers-sffnumbers": {
		"extensions": ["numbers"]
	},
	"application/x-iwork-pages-sffpages": {
		"extensions": ["pages"]
	},
	"application/x-java-archive-diff": {
		"source": SOURCE.NGINX,
		"extensions": ["jardiff"]
	},
	"application/x-java-jnlp-file": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["jnlp"]
	},
	"application/x-javascript": {
		"compressible": true
	},
	"application/x-keepass2": {
		"extensions": ["kraw_dbx"]
	},
	"application/x-latex": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["latex"]
	},
	"application/x-lua-bytecode": {
		"extensions": ["luac"]
	},
	"application/x-lzh-compressed": {
		"source": SOURCE.APACHE,
		"extensions": ["lzh","lha"]
	},
	"application/x-makeself": {
		"source": SOURCE.NGINX,
		"extensions": ["run"]
	},
	"application/x-mie": {
		"source": SOURCE.APACHE,
		"extensions": ["mie"]
	},
	"application/x-mobipocket-ebook": {
		"source": SOURCE.APACHE,
		"extensions": ["prc","mobi"]
	},
	"application/x-mpegurl": {
		"compressible": false
	},
	"application/x-ms-application": {
		"source": SOURCE.APACHE,
		"extensions": ["application"]
	},
	"application/x-ms-shortcut": {
		"source": SOURCE.APACHE,
		"extensions": ["lnk"]
	},
	"application/x-ms-wmd": {
		"source": SOURCE.APACHE,
		"extensions": ["wmd"]
	},
	"application/x-ms-wmz": {
		"source": SOURCE.APACHE,
		"extensions": ["wmz"]
	},
	"application/x-ms-xbap": {
		"source": SOURCE.APACHE,
		"extensions": ["xbap"]
	},
	"application/x-msaccess": {
		"source": SOURCE.APACHE,
		"extensions": ["mraw_db"]
	},
	"application/x-msbinder": {
		"source": SOURCE.APACHE,
		"extensions": ["obd"]
	},
	"application/x-mscardfile": {
		"source": SOURCE.APACHE,
		"extensions": ["crd"]
	},
	"application/x-msclip": {
		"source": SOURCE.APACHE,
		"extensions": ["clp"]
	},
	"application/x-msdos-program": {
		"extensions": ["exe"]
	},
	"application/x-msdownload": {
		"source": SOURCE.APACHE,
		"extensions": ["exe","dll","com","bat","msi"]
	},
	"application/x-msmediaview": {
		"source": SOURCE.APACHE,
		"extensions": ["mvb","m13","m14"]
	},
	"application/x-msmetafile": {
		"source": SOURCE.APACHE,
		"extensions": ["wmf","wmz","emf","emz"]
	},
	"application/x-msmoney": {
		"source": SOURCE.APACHE,
		"extensions": ["mny"]
	},
	"application/x-mspublisher": {
		"source": SOURCE.APACHE,
		"extensions": ["pub"]
	},
	"application/x-msschedule": {
		"source": SOURCE.APACHE,
		"extensions": ["scd"]
	},
	"application/x-msterminal": {
		"source": SOURCE.APACHE,
		"extensions": ["trm"]
	},
	"application/x-mswrite": {
		"source": SOURCE.APACHE,
		"extensions": ["wri"]
	},
	"application/x-netcdf": {
		"source": SOURCE.APACHE,
		"extensions": ["nc","cdf"]
	},
	"application/x-ns-proxy-autoconfig": {
		"compressible": true,
		"extensions": ["pac"]
	},
	"application/x-nzb": {
		"source": SOURCE.APACHE,
		"extensions": ["nzb"]
	},
	"application/x-perl": {
		"source": SOURCE.NGINX,
		"extensions": ["pl","pm"]
	},
	"application/x-pilot": {
		"source": SOURCE.NGINX,
		"extensions": ["prc","praw_db"]
	},
	"application/x-pkcs12": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["p12","pfx"]
	},
	"application/x-pkcs7-certificates": {
		"source": SOURCE.APACHE,
		"extensions": ["p7b","spc"]
	},
	"application/x-pkcs7-certreqresp": {
		"source": SOURCE.APACHE,
		"extensions": ["p7r"]
	},
	"application/x-pki-message": {
		"source": SOURCE.IANA
	},
	"application/x-rar-compressed": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["rar"]
	},
	"application/x-redhat-package-manager": {
		"source": SOURCE.NGINX,
		"extensions": ["rpm"]
	},
	"application/x-research-info-systems": {
		"source": SOURCE.APACHE,
		"extensions": ["ris"]
	},
	"application/x-sea": {
		"source": SOURCE.NGINX,
		"extensions": ["sea"]
	},
	"application/x-sh": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["sh"]
	},
	"application/x-shar": {
		"source": SOURCE.APACHE,
		"extensions": ["shar"]
	},
	"application/x-shockwave-flash": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["swf"]
	},
	"application/x-silverlight-app": {
		"source": SOURCE.APACHE,
		"extensions": ["xap"]
	},
	"application/x-sql": {
		"source": SOURCE.APACHE,
		"extensions": ["sql"]
	},
	"application/x-stuffit": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["sit"]
	},
	"application/x-stuffitx": {
		"source": SOURCE.APACHE,
		"extensions": ["sitx"]
	},
	"application/x-subrip": {
		"source": SOURCE.APACHE,
		"extensions": ["srt"]
	},
	"application/x-sv4cpio": {
		"source": SOURCE.APACHE,
		"extensions": ["sv4cpio"]
	},
	"application/x-sv4crc": {
		"source": SOURCE.APACHE,
		"extensions": ["sv4crc"]
	},
	"application/x-t3vm-image": {
		"source": SOURCE.APACHE,
		"extensions": ["t3"]
	},
	"application/x-tads": {
		"source": SOURCE.APACHE,
		"extensions": ["gam"]
	},
	"application/x-tar": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["tar"]
	},
	"application/x-tcl": {
		"source": SOURCE.APACHE,
		"extensions": ["tcl","tk"]
	},
	"application/x-tex": {
		"source": SOURCE.APACHE,
		"extensions": ["tex"]
	},
	"application/x-tex-tfm": {
		"source": SOURCE.APACHE,
		"extensions": ["tfm"]
	},
	"application/x-texinfo": {
		"source": SOURCE.APACHE,
		"extensions": ["texinfo","texi"]
	},
	"application/x-tgif": {
		"source": SOURCE.APACHE,
		"extensions": ["obj"]
	},
	"application/x-ustar": {
		"source": SOURCE.APACHE,
		"extensions": ["ustar"]
	},
	"application/x-virtualbox-hdd": {
		"compressible": true,
		"extensions": ["hdd"]
	},
	"application/x-virtualbox-ova": {
		"compressible": true,
		"extensions": ["ova"]
	},
	"application/x-virtualbox-ovf": {
		"compressible": true,
		"extensions": ["ovf"]
	},
	"application/x-virtualbox-vbox": {
		"compressible": true,
		"extensions": ["vbox"]
	},
	"application/x-virtualbox-vbox-extpack": {
		"compressible": false,
		"extensions": ["vbox-extpack"]
	},
	"application/x-virtualbox-vdi": {
		"compressible": true,
		"extensions": ["vdi"]
	},
	"application/x-virtualbox-vhd": {
		"compressible": true,
		"extensions": ["vhd"]
	},
	"application/x-virtualbox-vmdk": {
		"compressible": true,
		"extensions": ["vmdk"]
	},
	"application/x-wais-source": {
		"source": SOURCE.APACHE,
		"extensions": ["src"]
	},
	"application/x-web-app-manifest+json": {
		"compressible": true,
		"extensions": ["webapp"]
	},
	"application/x-www-form-urlencoded": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/x-x509-ca-cert": {
		"source": SOURCE.IANA,
		"extensions": ["der","crt","pem"]
	},
	"application/x-x509-ca-ra-cert": {
		"source": SOURCE.IANA
	},
	"application/x-x509-next-ca-cert": {
		"source": SOURCE.IANA
	},
	"application/x-xfig": {
		"source": SOURCE.APACHE,
		"extensions": ["fig"]
	},
	"application/x-xliff+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["xlf"]
	},
	"application/x-xpinstall": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["xpi"]
	},
	"application/x-xz": {
		"source": SOURCE.APACHE,
		"extensions": ["xz"]
	},
	"application/x-zmachine": {
		"source": SOURCE.APACHE,
		"extensions": ["z1","z2","z3","z4","z5","z6","z7","z8"]
	},
	"application/x400-bp": {
		"source": SOURCE.IANA
	},
	"application/xacml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xaml+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["xaml"]
	},
	"application/xcap-att+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xav"]
	},
	"application/xcap-caps+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xca"]
	},
	"application/xcap-diff+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xdf"]
	},
	"application/xcap-el+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xel"]
	},
	"application/xcap-error+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xcap-ns+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xns"]
	},
	"application/xcon-conference-info+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xcon-conference-info-diff+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xenc+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xenc"]
	},
	"application/xfdf": {
		"source": SOURCE.IANA,
		"extensions": ["xfdf"]
	},
	"application/xhtml+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xhtml","xht"]
	},
	"application/xhtml-voice+xml": {
		"source": SOURCE.APACHE,
		"compressible": true
	},
	"application/xliff+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xlf"]
	},
	"application/xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xml","xsl","xsd","rng"]
	},
	"application/xml-dtd": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["dtd"]
	},
	"application/xml-external-parsed-entity": {
		"source": SOURCE.IANA
	},
	"application/xml-patch+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xmpp+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/xop+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xop"]
	},
	"application/xproc+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["xpl"]
	},
	"application/xslt+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xsl","xslt"]
	},
	"application/xspf+xml": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["xspf"]
	},
	"application/xv+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["mxml","xhvml","xvml","xvm"]
	},
	"application/yang": {
		"source": SOURCE.IANA,
		"extensions": ["yang"]
	},
	"application/yang-data+cbor": {
		"source": SOURCE.IANA
	},
	"application/yang-data+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/yang-data+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/yang-patch+json": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/yang-patch+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"application/yin+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["yin"]
	},
	"application/zip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["zip"]
	},
	"application/zlib": {
		"source": SOURCE.IANA
	},
	"application/zstd": {
		"source": SOURCE.IANA
	},
	"audio/1d-interleaved-parityfec": {
		"source": SOURCE.IANA
	},
	"audio/32kadpcm": {
		"source": SOURCE.IANA
	},
	"audio/3gpp": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["3gpp"]
	},
	"audio/3gpp2": {
		"source": SOURCE.IANA
	},
	"audio/aac": {
		"source": SOURCE.IANA,
		"extensions": ["adts","aac"]
	},
	"audio/ac3": {
		"source": SOURCE.IANA
	},
	"audio/adpcm": {
		"source": SOURCE.APACHE,
		"extensions": ["adp"]
	},
	"audio/amr": {
		"source": SOURCE.IANA,
		"extensions": ["amr"]
	},
	"audio/amr-wb": {
		"source": SOURCE.IANA
	},
	"audio/amr-wb+": {
		"source": SOURCE.IANA
	},
	"audio/aptx": {
		"source": SOURCE.IANA
	},
	"audio/asc": {
		"source": SOURCE.IANA
	},
	"audio/atrac-advanced-lossless": {
		"source": SOURCE.IANA
	},
	"audio/atrac-x": {
		"source": SOURCE.IANA
	},
	"audio/atrac3": {
		"source": SOURCE.IANA
	},
	"audio/basic": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["au","snd"]
	},
	"audio/bv16": {
		"source": SOURCE.IANA
	},
	"audio/bv32": {
		"source": SOURCE.IANA
	},
	"audio/clearmode": {
		"source": SOURCE.IANA
	},
	"audio/cn": {
		"source": SOURCE.IANA
	},
	"audio/dat12": {
		"source": SOURCE.IANA
	},
	"audio/dls": {
		"source": SOURCE.IANA
	},
	"audio/dsr-es201108": {
		"source": SOURCE.IANA
	},
	"audio/dsr-es202050": {
		"source": SOURCE.IANA
	},
	"audio/dsr-es202211": {
		"source": SOURCE.IANA
	},
	"audio/dsr-es202212": {
		"source": SOURCE.IANA
	},
	"audio/dv": {
		"source": SOURCE.IANA
	},
	"audio/dvi4": {
		"source": SOURCE.IANA
	},
	"audio/eac3": {
		"source": SOURCE.IANA
	},
	"audio/encaprtp": {
		"source": SOURCE.IANA
	},
	"audio/evrc": {
		"source": SOURCE.IANA
	},
	"audio/evrc-qcp": {
		"source": SOURCE.IANA
	},
	"audio/evrc0": {
		"source": SOURCE.IANA
	},
	"audio/evrc1": {
		"source": SOURCE.IANA
	},
	"audio/evrcb": {
		"source": SOURCE.IANA
	},
	"audio/evrcb0": {
		"source": SOURCE.IANA
	},
	"audio/evrcb1": {
		"source": SOURCE.IANA
	},
	"audio/evrcnw": {
		"source": SOURCE.IANA
	},
	"audio/evrcnw0": {
		"source": SOURCE.IANA
	},
	"audio/evrcnw1": {
		"source": SOURCE.IANA
	},
	"audio/evrcwb": {
		"source": SOURCE.IANA
	},
	"audio/evrcwb0": {
		"source": SOURCE.IANA
	},
	"audio/evrcwb1": {
		"source": SOURCE.IANA
	},
	"audio/evs": {
		"source": SOURCE.IANA
	},
	"audio/flexfec": {
		"source": SOURCE.IANA
	},
	"audio/fwdred": {
		"source": SOURCE.IANA
	},
	"audio/g711-0": {
		"source": SOURCE.IANA
	},
	"audio/g719": {
		"source": SOURCE.IANA
	},
	"audio/g722": {
		"source": SOURCE.IANA
	},
	"audio/g7221": {
		"source": SOURCE.IANA
	},
	"audio/g723": {
		"source": SOURCE.IANA
	},
	"audio/g726-16": {
		"source": SOURCE.IANA
	},
	"audio/g726-24": {
		"source": SOURCE.IANA
	},
	"audio/g726-32": {
		"source": SOURCE.IANA
	},
	"audio/g726-40": {
		"source": SOURCE.IANA
	},
	"audio/g728": {
		"source": SOURCE.IANA
	},
	"audio/g729": {
		"source": SOURCE.IANA
	},
	"audio/g7291": {
		"source": SOURCE.IANA
	},
	"audio/g729d": {
		"source": SOURCE.IANA
	},
	"audio/g729e": {
		"source": SOURCE.IANA
	},
	"audio/gsm": {
		"source": SOURCE.IANA
	},
	"audio/gsm-efr": {
		"source": SOURCE.IANA
	},
	"audio/gsm-hr-08": {
		"source": SOURCE.IANA
	},
	"audio/ilbc": {
		"source": SOURCE.IANA
	},
	"audio/ip-mr_v2.5": {
		"source": SOURCE.IANA
	},
	"audio/isac": {
		"source": SOURCE.APACHE
	},
	"audio/l16": {
		"source": SOURCE.IANA
	},
	"audio/l20": {
		"source": SOURCE.IANA
	},
	"audio/l24": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"audio/l8": {
		"source": SOURCE.IANA
	},
	"audio/lpc": {
		"source": SOURCE.IANA
	},
	"audio/melp": {
		"source": SOURCE.IANA
	},
	"audio/melp1200": {
		"source": SOURCE.IANA
	},
	"audio/melp2400": {
		"source": SOURCE.IANA
	},
	"audio/melp600": {
		"source": SOURCE.IANA
	},
	"audio/mhas": {
		"source": SOURCE.IANA
	},
	"audio/midi": {
		"source": SOURCE.APACHE,
		"extensions": ["mid","midi","kar","rmi"]
	},
	"audio/mobile-xmf": {
		"source": SOURCE.IANA,
		"extensions": ["mxmf"]
	},
	"audio/mp3": {
		"compressible": false,
		"extensions": ["mp3"]
	},
	"audio/mp4": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["m4a","mp4a"]
	},
	"audio/mp4a-latm": {
		"source": SOURCE.IANA
	},
	"audio/mpa": {
		"source": SOURCE.IANA
	},
	"audio/mpa-robust": {
		"source": SOURCE.IANA
	},
	"audio/mpeg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["mpga","mp2","mp2a","mp3","m2a","m3a"]
	},
	"audio/mpeg4-generic": {
		"source": SOURCE.IANA
	},
	"audio/musepack": {
		"source": SOURCE.APACHE
	},
	"audio/ogg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["oga","ogg","spx","opus"]
	},
	"audio/opus": {
		"source": SOURCE.IANA
	},
	"audio/parityfec": {
		"source": SOURCE.IANA
	},
	"audio/pcma": {
		"source": SOURCE.IANA
	},
	"audio/pcma-wb": {
		"source": SOURCE.IANA
	},
	"audio/pcmu": {
		"source": SOURCE.IANA
	},
	"audio/pcmu-wb": {
		"source": SOURCE.IANA
	},
	"audio/prs.sid": {
		"source": SOURCE.IANA
	},
	"audio/qcelp": {
		"source": SOURCE.IANA
	},
	"audio/raptorfec": {
		"source": SOURCE.IANA
	},
	"audio/red": {
		"source": SOURCE.IANA
	},
	"audio/rtp-enc-aescm128": {
		"source": SOURCE.IANA
	},
	"audio/rtp-midi": {
		"source": SOURCE.IANA
	},
	"audio/rtploopback": {
		"source": SOURCE.IANA
	},
	"audio/rtx": {
		"source": SOURCE.IANA
	},
	"audio/s3m": {
		"source": SOURCE.APACHE,
		"extensions": ["s3m"]
	},
	"audio/scip": {
		"source": SOURCE.IANA
	},
	"audio/silk": {
		"source": SOURCE.APACHE,
		"extensions": ["sil"]
	},
	"audio/smv": {
		"source": SOURCE.IANA
	},
	"audio/smv-qcp": {
		"source": SOURCE.IANA
	},
	"audio/smv0": {
		"source": SOURCE.IANA
	},
	"audio/sofa": {
		"source": SOURCE.IANA
	},
	"audio/sp-midi": {
		"source": SOURCE.IANA
	},
	"audio/speex": {
		"source": SOURCE.IANA
	},
	"audio/t140c": {
		"source": SOURCE.IANA
	},
	"audio/t38": {
		"source": SOURCE.IANA
	},
	"audio/telephone-event": {
		"source": SOURCE.IANA
	},
	"audio/tetra_acelp": {
		"source": SOURCE.IANA
	},
	"audio/tetra_acelp_bb": {
		"source": SOURCE.IANA
	},
	"audio/tone": {
		"source": SOURCE.IANA
	},
	"audio/tsvcis": {
		"source": SOURCE.IANA
	},
	"audio/uemclip": {
		"source": SOURCE.IANA
	},
	"audio/ulpfec": {
		"source": SOURCE.IANA
	},
	"audio/usac": {
		"source": SOURCE.IANA
	},
	"audio/vdvi": {
		"source": SOURCE.IANA
	},
	"audio/vmr-wb": {
		"source": SOURCE.IANA
	},
	"audio/vnd.3gpp.iufp": {
		"source": SOURCE.IANA
	},
	"audio/vnd.4sb": {
		"source": SOURCE.IANA
	},
	"audio/vnd.audiokoz": {
		"source": SOURCE.IANA
	},
	"audio/vnd.celp": {
		"source": SOURCE.IANA
	},
	"audio/vnd.cisco.nse": {
		"source": SOURCE.IANA
	},
	"audio/vnd.cmles.radio-events": {
		"source": SOURCE.IANA
	},
	"audio/vnd.cns.anp1": {
		"source": SOURCE.IANA
	},
	"audio/vnd.cns.inf1": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dece.audio": {
		"source": SOURCE.IANA,
		"extensions": ["uva","uvva"]
	},
	"audio/vnd.digital-winds": {
		"source": SOURCE.IANA,
		"extensions": ["eol"]
	},
	"audio/vnd.dlna.adts": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.heaac.1": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.heaac.2": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.mlp": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.mps": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.pl2": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.pl2x": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.pl2z": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dolby.pulse.1": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dra": {
		"source": SOURCE.IANA,
		"extensions": ["dra"]
	},
	"audio/vnd.dts": {
		"source": SOURCE.IANA,
		"extensions": ["dts"]
	},
	"audio/vnd.dts.hd": {
		"source": SOURCE.IANA,
		"extensions": ["dtshd"]
	},
	"audio/vnd.dts.uhd": {
		"source": SOURCE.IANA
	},
	"audio/vnd.dvb.file": {
		"source": SOURCE.IANA
	},
	"audio/vnd.everad.plj": {
		"source": SOURCE.IANA
	},
	"audio/vnd.hns.audio": {
		"source": SOURCE.IANA
	},
	"audio/vnd.lucent.voice": {
		"source": SOURCE.IANA,
		"extensions": ["lvp"]
	},
	"audio/vnd.ms-playready.media.pya": {
		"source": SOURCE.IANA,
		"extensions": ["pya"]
	},
	"audio/vnd.nokia.mobile-xmf": {
		"source": SOURCE.IANA
	},
	"audio/vnd.nortel.vbk": {
		"source": SOURCE.IANA
	},
	"audio/vnd.nuera.ecelp4800": {
		"source": SOURCE.IANA,
		"extensions": ["ecelp4800"]
	},
	"audio/vnd.nuera.ecelp7470": {
		"source": SOURCE.IANA,
		"extensions": ["ecelp7470"]
	},
	"audio/vnd.nuera.ecelp9600": {
		"source": SOURCE.IANA,
		"extensions": ["ecelp9600"]
	},
	"audio/vnd.octel.sbc": {
		"source": SOURCE.IANA
	},
	"audio/vnd.presonus.multitrack": {
		"source": SOURCE.IANA
	},
	"audio/vnd.qcelp": {
		"source": SOURCE.APACHE
	},
	"audio/vnd.rhetorex.32kadpcm": {
		"source": SOURCE.IANA
	},
	"audio/vnd.rip": {
		"source": SOURCE.IANA,
		"extensions": ["rip"]
	},
	"audio/vnd.rn-realaudio": {
		"compressible": false
	},
	"audio/vnd.sealedmedia.softseal.mpeg": {
		"source": SOURCE.IANA
	},
	"audio/vnd.vmx.cvsd": {
		"source": SOURCE.IANA
	},
	"audio/vnd.wave": {
		"compressible": false
	},
	"audio/vorbis": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"audio/vorbis-config": {
		"source": SOURCE.IANA
	},
	"audio/wav": {
		"compressible": false,
		"extensions": ["wav"]
	},
	"audio/wave": {
		"compressible": false,
		"extensions": ["wav"]
	},
	"audio/webm": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["weba"]
	},
	"audio/x-aac": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["aac"]
	},
	"audio/x-aiff": {
		"source": SOURCE.APACHE,
		"extensions": ["aif","aiff","aifc"]
	},
	"audio/x-caf": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["caf"]
	},
	"audio/x-flac": {
		"source": SOURCE.APACHE,
		"extensions": ["flac"]
	},
	"audio/x-m4a": {
		"source": SOURCE.NGINX,
		"extensions": ["m4a"]
	},
	"audio/x-matroska": {
		"source": SOURCE.APACHE,
		"extensions": ["mka"]
	},
	"audio/x-mpegurl": {
		"source": SOURCE.APACHE,
		"extensions": ["m3u"]
	},
	"audio/x-ms-wax": {
		"source": SOURCE.APACHE,
		"extensions": ["wax"]
	},
	"audio/x-ms-wma": {
		"source": SOURCE.APACHE,
		"extensions": ["wma"]
	},
	"audio/x-pn-realaudio": {
		"source": SOURCE.APACHE,
		"extensions": ["ram","ra"]
	},
	"audio/x-pn-realaudio-plugin": {
		"source": SOURCE.APACHE,
		"extensions": ["rmp"]
	},
	"audio/x-realaudio": {
		"source": SOURCE.NGINX,
		"extensions": ["ra"]
	},
	"audio/x-tta": {
		"source": SOURCE.APACHE
	},
	"audio/x-wav": {
		"source": SOURCE.APACHE,
		"extensions": ["wav"]
	},
	"audio/xm": {
		"source": SOURCE.APACHE,
		"extensions": ["xm"]
	},
	"chemical/x-cdx": {
		"source": SOURCE.APACHE,
		"extensions": ["cdx"]
	},
	"chemical/x-cif": {
		"source": SOURCE.APACHE,
		"extensions": ["cif"]
	},
	"chemical/x-cmdf": {
		"source": SOURCE.APACHE,
		"extensions": ["cmdf"]
	},
	"chemical/x-cml": {
		"source": SOURCE.APACHE,
		"extensions": ["cml"]
	},
	"chemical/x-csml": {
		"source": SOURCE.APACHE,
		"extensions": ["csml"]
	},
	"chemical/x-praw_db": {
		"source": SOURCE.APACHE
	},
	"chemical/x-xyz": {
		"source": SOURCE.APACHE,
		"extensions": ["xyz"]
	},
	"font/collection": {
		"source": SOURCE.IANA,
		"extensions": ["ttc"]
	},
	"font/otf": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["otf"]
	},
	"font/sfnt": {
		"source": SOURCE.IANA
	},
	"font/ttf": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ttf"]
	},
	"font/woff": {
		"source": SOURCE.IANA,
		"extensions": ["woff"]
	},
	"font/woff2": {
		"source": SOURCE.IANA,
		"extensions": ["woff2"]
	},
	"image/aces": {
		"source": SOURCE.IANA,
		"extensions": ["exr"]
	},
	"image/apng": {
		"compressible": false,
		"extensions": ["apng"]
	},
	"image/avci": {
		"source": SOURCE.IANA,
		"extensions": ["avci"]
	},
	"image/avcs": {
		"source": SOURCE.IANA,
		"extensions": ["avcs"]
	},
	"image/avif": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["avif"]
	},
	"image/bmp": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["bmp","dib"]
	},
	"image/cgm": {
		"source": SOURCE.IANA,
		"extensions": ["cgm"]
	},
	"image/dicom-rle": {
		"source": SOURCE.IANA,
		"extensions": ["drle"]
	},
	"image/emf": {
		"source": SOURCE.IANA,
		"extensions": ["emf"]
	},
	"image/fits": {
		"source": SOURCE.IANA,
		"extensions": ["fits"]
	},
	"image/g3fax": {
		"source": SOURCE.IANA,
		"extensions": ["g3"]
	},
	"image/gif": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["gif"]
	},
	"image/heic": {
		"source": SOURCE.IANA,
		"extensions": ["heic"]
	},
	"image/heic-sequence": {
		"source": SOURCE.IANA,
		"extensions": ["heics"]
	},
	"image/heif": {
		"source": SOURCE.IANA,
		"extensions": ["heif"]
	},
	"image/heif-sequence": {
		"source": SOURCE.IANA,
		"extensions": ["heifs"]
	},
	"image/hej2k": {
		"source": SOURCE.IANA,
		"extensions": ["hej2"]
	},
	"image/hsj2": {
		"source": SOURCE.IANA,
		"extensions": ["hsj2"]
	},
	"image/ief": {
		"source": SOURCE.IANA,
		"extensions": ["ief"]
	},
	"image/jls": {
		"source": SOURCE.IANA,
		"extensions": ["jls"]
	},
	"image/jp2": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["jp2","jpg2"]
	},
	"image/jpeg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["jpeg","jpg","jpe"]
	},
	"image/jph": {
		"source": SOURCE.IANA,
		"extensions": ["jph"]
	},
	"image/jphc": {
		"source": SOURCE.IANA,
		"extensions": ["jhc"]
	},
	"image/jpm": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["jpm"]
	},
	"image/jpx": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["jpx","jpf"]
	},
	"image/jxr": {
		"source": SOURCE.IANA,
		"extensions": ["jxr"]
	},
	"image/jxra": {
		"source": SOURCE.IANA,
		"extensions": ["jxra"]
	},
	"image/jxrs": {
		"source": SOURCE.IANA,
		"extensions": ["jxrs"]
	},
	"image/jxs": {
		"source": SOURCE.IANA,
		"extensions": ["jxs"]
	},
	"image/jxsc": {
		"source": SOURCE.IANA,
		"extensions": ["jxsc"]
	},
	"image/jxsi": {
		"source": SOURCE.IANA,
		"extensions": ["jxsi"]
	},
	"image/jxss": {
		"source": SOURCE.IANA,
		"extensions": ["jxss"]
	},
	"image/ktx": {
		"source": SOURCE.IANA,
		"extensions": ["ktx"]
	},
	"image/ktx2": {
		"source": SOURCE.IANA,
		"extensions": ["ktx2"]
	},
	"image/naplps": {
		"source": SOURCE.IANA
	},
	"image/pjpeg": {
		"compressible": false
	},
	"image/png": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["png"]
	},
	"image/prs.btif": {
		"source": SOURCE.IANA,
		"extensions": ["btif","btf"]
	},
	"image/prs.pti": {
		"source": SOURCE.IANA,
		"extensions": ["pti"]
	},
	"image/pwg-raster": {
		"source": SOURCE.IANA
	},
	"image/sgi": {
		"source": SOURCE.APACHE,
		"extensions": ["sgi"]
	},
	"image/svg+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["svg","svgz"]
	},
	"image/t38": {
		"source": SOURCE.IANA,
		"extensions": ["t38"]
	},
	"image/tiff": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["tif","tiff"]
	},
	"image/tiff-fx": {
		"source": SOURCE.IANA,
		"extensions": ["tfx"]
	},
	"image/vnd.adobe.photoshop": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["psd"]
	},
	"image/vnd.airzip.accelerator.azv": {
		"source": SOURCE.IANA,
		"extensions": ["azv"]
	},
	"image/vnd.cns.inf2": {
		"source": SOURCE.IANA
	},
	"image/vnd.dece.graphic": {
		"source": SOURCE.IANA,
		"extensions": ["uvi","uvvi","uvg","uvvg"]
	},
	"image/vnd.djvu": {
		"source": SOURCE.IANA,
		"extensions": ["djvu","djv"]
	},
	"image/vnd.dvb.subtitle": {
		"source": SOURCE.IANA,
		"extensions": ["sub"]
	},
	"image/vnd.dwg": {
		"source": SOURCE.IANA,
		"extensions": ["dwg"]
	},
	"image/vnd.dxf": {
		"source": SOURCE.IANA,
		"extensions": ["dxf"]
	},
	"image/vnd.fastbidsheet": {
		"source": SOURCE.IANA,
		"extensions": ["fbs"]
	},
	"image/vnd.fpx": {
		"source": SOURCE.IANA,
		"extensions": ["fpx"]
	},
	"image/vnd.fst": {
		"source": SOURCE.IANA,
		"extensions": ["fst"]
	},
	"image/vnd.fujixerox.edmics-mmr": {
		"source": SOURCE.IANA,
		"extensions": ["mmr"]
	},
	"image/vnd.fujixerox.edmics-rlc": {
		"source": SOURCE.IANA,
		"extensions": ["rlc"]
	},
	"image/vnd.globalgraphics.pgb": {
		"source": SOURCE.IANA
	},
	"image/vnd.microsoft.icon": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["ico"]
	},
	"image/vnd.mix": {
		"source": SOURCE.IANA
	},
	"image/vnd.mozilla.apng": {
		"source": SOURCE.IANA,
		"extensions": ["apng"]
	},
	"image/vnd.ms-dds": {
		"compressible": true,
		"extensions": ["dds"]
	},
	"image/vnd.ms-modi": {
		"source": SOURCE.IANA,
		"extensions": ["mdi"]
	},
	"image/vnd.ms-photo": {
		"source": SOURCE.APACHE,
		"extensions": ["wdp"]
	},
	"image/vnd.net-fpx": {
		"source": SOURCE.IANA,
		"extensions": ["npx"]
	},
	"image/vnd.pco.b16": {
		"source": SOURCE.IANA,
		"extensions": ["b16"]
	},
	"image/vnd.radiance": {
		"source": SOURCE.IANA
	},
	"image/vnd.sealed.png": {
		"source": SOURCE.IANA
	},
	"image/vnd.sealedmedia.softseal.gif": {
		"source": SOURCE.IANA
	},
	"image/vnd.sealedmedia.softseal.jpg": {
		"source": SOURCE.IANA
	},
	"image/vnd.svf": {
		"source": SOURCE.IANA
	},
	"image/vnd.tencent.tap": {
		"source": SOURCE.IANA,
		"extensions": ["tap"]
	},
	"image/vnd.valve.source.texture": {
		"source": SOURCE.IANA,
		"extensions": ["vtf"]
	},
	"image/vnd.wap.wbmp": {
		"source": SOURCE.IANA,
		"extensions": ["wbmp"]
	},
	"image/vnd.xiff": {
		"source": SOURCE.IANA,
		"extensions": ["xif"]
	},
	"image/vnd.zbrush.pcx": {
		"source": SOURCE.IANA,
		"extensions": ["pcx"]
	},
	"image/webp": {
		"source": SOURCE.APACHE,
		"extensions": ["webp"]
	},
	"image/wmf": {
		"source": SOURCE.IANA,
		"extensions": ["wmf"]
	},
	"image/x-3ds": {
		"source": SOURCE.APACHE,
		"extensions": ["3ds"]
	},
	"image/x-cmu-raster": {
		"source": SOURCE.APACHE,
		"extensions": ["ras"]
	},
	"image/x-cmx": {
		"source": SOURCE.APACHE,
		"extensions": ["cmx"]
	},
	"image/x-freehand": {
		"source": SOURCE.APACHE,
		"extensions": ["fh","fhc","fh4","fh5","fh7"]
	},
	"image/x-icon": {
		"source": SOURCE.APACHE,
		"compressible": true,
		"extensions": ["ico"]
	},
	"image/x-jng": {
		"source": SOURCE.NGINX,
		"extensions": ["jng"]
	},
	"image/x-mrsid-image": {
		"source": SOURCE.APACHE,
		"extensions": ["sid"]
	},
	"image/x-ms-bmp": {
		"source": SOURCE.NGINX,
		"compressible": true,
		"extensions": ["bmp"]
	},
	"image/x-pcx": {
		"source": SOURCE.APACHE,
		"extensions": ["pcx"]
	},
	"image/x-pict": {
		"source": SOURCE.APACHE,
		"extensions": ["pic","pct"]
	},
	"image/x-portable-anymap": {
		"source": SOURCE.APACHE,
		"extensions": ["pnm"]
	},
	"image/x-portable-bitmap": {
		"source": SOURCE.APACHE,
		"extensions": ["pbm"]
	},
	"image/x-portable-graymap": {
		"source": SOURCE.APACHE,
		"extensions": ["pgm"]
	},
	"image/x-portable-pixmap": {
		"source": SOURCE.APACHE,
		"extensions": ["ppm"]
	},
	"image/x-rgb": {
		"source": SOURCE.APACHE,
		"extensions": ["rgb"]
	},
	"image/x-tga": {
		"source": SOURCE.APACHE,
		"extensions": ["tga"]
	},
	"image/x-xbitmap": {
		"source": SOURCE.APACHE,
		"extensions": ["xbm"]
	},
	"image/x-xcf": {
		"compressible": false
	},
	"image/x-xpixmap": {
		"source": SOURCE.APACHE,
		"extensions": ["xpm"]
	},
	"image/x-xwindowdump": {
		"source": SOURCE.APACHE,
		"extensions": ["xwd"]
	},
	"message/cpim": {
		"source": SOURCE.IANA
	},
	"message/delivery-status": {
		"source": SOURCE.IANA
	},
	"message/disposition-notification": {
		"source": SOURCE.IANA,
		"extensions": [
		"disposition-notification"
	]
	},
	"message/external-body": {
		"source": SOURCE.IANA
	},
	"message/feeraw_dback-report": {
		"source": SOURCE.IANA
	},
	"message/global": {
		"source": SOURCE.IANA,
		"extensions": ["u8msg"]
	},
	"message/global-delivery-status": {
		"source": SOURCE.IANA,
		"extensions": ["u8dsn"]
	},
	"message/global-disposition-notification": {
		"source": SOURCE.IANA,
		"extensions": ["u8mdn"]
	},
	"message/global-headers": {
		"source": SOURCE.IANA,
		"extensions": ["u8hdr"]
	},
	"message/http": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"message/imdn+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"message/news": {
		"source": SOURCE.APACHE
	},
	"message/partial": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"message/rfc822": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["eml","mime"]
	},
	"message/s-http": {
		"source": SOURCE.APACHE
	},
	"message/sip": {
		"source": SOURCE.IANA
	},
	"message/sipfrag": {
		"source": SOURCE.IANA
	},
	"message/tracking-status": {
		"source": SOURCE.IANA
	},
	"message/vnd.si.simp": {
		"source": SOURCE.APACHE
	},
	"message/vnd.wfa.wsc": {
		"source": SOURCE.IANA,
		"extensions": ["wsc"]
	},
	"model/3mf": {
		"source": SOURCE.IANA,
		"extensions": ["3mf"]
	},
	"model/e57": {
		"source": SOURCE.IANA
	},
	"model/gltf+json": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["gltf"]
	},
	"model/gltf-binary": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["glb"]
	},
	"model/iges": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["igs","iges"]
	},
	"model/mesh": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["msh","mesh","silo"]
	},
	"model/mtl": {
		"source": SOURCE.IANA,
		"extensions": ["mtl"]
	},
	"model/obj": {
		"source": SOURCE.IANA,
		"extensions": ["obj"]
	},
	"model/prc": {
		"source": SOURCE.IANA,
		"extensions": ["prc"]
	},
	"model/step": {
		"source": SOURCE.IANA
	},
	"model/step+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["stpx"]
	},
	"model/step+zip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["stpz"]
	},
	"model/step-xml+zip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["stpxz"]
	},
	"model/stl": {
		"source": SOURCE.IANA,
		"extensions": ["stl"]
	},
	"model/u3d": {
		"source": SOURCE.IANA,
		"extensions": ["u3d"]
	},
	"model/vnd.collada+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["dae"]
	},
	"model/vnd.dwf": {
		"source": SOURCE.IANA,
		"extensions": ["dwf"]
	},
	"model/vnd.flatland.3dml": {
		"source": SOURCE.IANA
	},
	"model/vnd.gdl": {
		"source": SOURCE.IANA,
		"extensions": ["gdl"]
	},
	"model/vnd.gs-gdl": {
		"source": SOURCE.APACHE
	},
	"model/vnd.gs.gdl": {
		"source": SOURCE.IANA
	},
	"model/vnd.gtw": {
		"source": SOURCE.IANA,
		"extensions": ["gtw"]
	},
	"model/vnd.moml+xml": {
		"source": SOURCE.IANA,
		"compressible": true
	},
	"model/vnd.mts": {
		"source": SOURCE.IANA,
		"extensions": ["mts"]
	},
	"model/vnd.opengex": {
		"source": SOURCE.IANA,
		"extensions": ["ogex"]
	},
	"model/vnd.parasolid.transmit.binary": {
		"source": SOURCE.IANA,
		"extensions": ["x_b"]
	},
	"model/vnd.parasolid.transmit.text": {
		"source": SOURCE.IANA,
		"extensions": ["x_t"]
	},
	"model/vnd.pytha.pyox": {
		"source": SOURCE.IANA,
		"extensions": ["pyo","pyox"]
	},
	"model/vnd.rosette.annotated-data-model": {
		"source": SOURCE.IANA
	},
	"model/vnd.sap.vds": {
		"source": SOURCE.IANA,
		"extensions": ["vds"]
	},
	"model/vnd.usdz+zip": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["usdz"]
	},
	"model/vnd.valve.source.compiled-map": {
		"source": SOURCE.IANA,
		"extensions": ["bsp"]
	},
	"model/vnd.vtu": {
		"source": SOURCE.IANA,
		"extensions": ["vtu"]
	},
	"model/vrml": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["wrl","vrml"]
	},
	"model/x3d+binary": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["x3raw_db","x3raw_dbz"]
	},
	"model/x3d+fastinfoset": {
		"source": SOURCE.IANA,
		"extensions": ["x3raw_db"]
	},
	"model/x3d+vrml": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["x3dv","x3dvz"]
	},
	"model/x3d+xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["x3d","x3dz"]
	},
	"model/x3d-vrml": {
		"source": SOURCE.IANA,
		"extensions": ["x3dv"]
	},
	"multipart/alternative": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"multipart/appledouble": {
		"source": SOURCE.IANA
	},
	"multipart/byteranges": {
		"source": SOURCE.IANA
	},
	"multipart/digest": {
		"source": SOURCE.IANA
	},
	"multipart/encrypted": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"multipart/form-data": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"multipart/header-set": {
		"source": SOURCE.IANA
	},
	"multipart/mixed": {
		"source": SOURCE.IANA
	},
	"multipart/multilingual": {
		"source": SOURCE.IANA
	},
	"multipart/parallel": {
		"source": SOURCE.IANA
	},
	"multipart/related": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"multipart/report": {
		"source": SOURCE.IANA
	},
	"multipart/signed": {
		"source": SOURCE.IANA,
		"compressible": false
	},
	"multipart/vnd.bint.med-plus": {
		"source": SOURCE.IANA
	},
	"multipart/voice-message": {
		"source": SOURCE.IANA
	},
	"multipart/x-mixed-replace": {
		"source": SOURCE.IANA
	},
	"text/1d-interleaved-parityfec": {
		"source": SOURCE.IANA
	},
	"text/cache-manifest": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["appcache","manifest"]
	},
	"text/calendar": {
		"source": SOURCE.IANA,
		"extensions": ["ics","ifb"]
	},
	"text/calender": {
		"compressible": true
	},
	"text/cmd": {
		"compressible": true
	},
	"text/coffeescript": {
		"extensions": ["coffee","litcoffee"]
	},
	"text/cql": {
		"source": SOURCE.IANA
	},
	"text/cql-expression": {
		"source": SOURCE.IANA
	},
	"text/cql-identifier": {
		"source": SOURCE.IANA
	},
	"text/css": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["css"]
	},
	"text/csv": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["csv"]
	},
	"text/csv-schema": {
		"source": SOURCE.IANA
	},
	"text/directory": {
		"source": SOURCE.IANA
	},
	"text/dns": {
		"source": SOURCE.IANA
	},
	"text/ecmascript": {
		"source": SOURCE.APACHE
	},
	"text/encaprtp": {
		"source": SOURCE.IANA
	},
	"text/enriched": {
		"source": SOURCE.IANA
	},
	"text/fhirpath": {
		"source": SOURCE.IANA
	},
	"text/flexfec": {
		"source": SOURCE.IANA
	},
	"text/fwdred": {
		"source": SOURCE.IANA
	},
	"text/gff3": {
		"source": SOURCE.IANA
	},
	"text/grammar-ref-list": {
		"source": SOURCE.IANA
	},
	"text/html": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["html","htm","shtml"]
	},
	"text/jade": {
		"extensions": ["jade"]
	},
	"text/javascript": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["js","mjs"]
	},
	"text/jcr-cnd": {
		"source": SOURCE.IANA
	},
	"text/jsx": {
		"compressible": true,
		"extensions": ["jsx"]
	},
	"text/less": {
		"compressible": true,
		"extensions": ["less"]
	},
	"text/markdown": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["md","markdown"]
	},
	"text/mathml": {
		"source": SOURCE.NGINX,
		"extensions": ["mml"]
	},
	"text/mdx": {
		"compressible": true,
		"extensions": ["mdx"]
	},
	"text/mizar": {
		"source": SOURCE.IANA
	},
	"text/n3": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["n3"]
	},
	"text/parameters": {
		"source": SOURCE.IANA,
		"charset": UTF8
	},
	"text/parityfec": {
		"source": SOURCE.IANA
	},
	"text/plain": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["txt","text","conf","def","list","log","in","ini"]
	},
	"text/provenance-notation": {
		"source": SOURCE.IANA,
		"charset": UTF8
	},
	"text/prs.fallenstein.rst": {
		"source": SOURCE.IANA
	},
	"text/prs.lines.tag": {
		"source": SOURCE.IANA,
		"extensions": ["dsc"]
	},
	"text/prs.prop.logic": {
		"source": SOURCE.IANA
	},
	"text/raptorfec": {
		"source": SOURCE.IANA
	},
	"text/red": {
		"source": SOURCE.IANA
	},
	"text/rfc822-headers": {
		"source": SOURCE.IANA
	},
	"text/richtext": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rtx"]
	},
	"text/rtf": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["rtf"]
	},
	"text/rtp-enc-aescm128": {
		"source": SOURCE.IANA
	},
	"text/rtploopback": {
		"source": SOURCE.IANA
	},
	"text/rtx": {
		"source": SOURCE.IANA
	},
	"text/sgml": {
		"source": SOURCE.IANA,
		"extensions": ["sgml","sgm"]
	},
	"text/shaclc": {
		"source": SOURCE.IANA
	},
	"text/shex": {
		"source": SOURCE.IANA,
		"extensions": ["shex"]
	},
	"text/slim": {
		"extensions": ["slim","slm"]
	},
	"text/spdx": {
		"source": SOURCE.IANA,
		"extensions": ["spdx"]
	},
	"text/strings": {
		"source": SOURCE.IANA
	},
	"text/stylus": {
		"extensions": ["stylus","styl"]
	},
	"text/t140": {
		"source": SOURCE.IANA
	},
	"text/tab-separated-values": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["tsv"]
	},
	"text/troff": {
		"source": SOURCE.IANA,
		"extensions": ["t","tr","roff","man","me","ms"]
	},
	"text/turtle": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"extensions": ["ttl"]
	},
	"text/ulpfec": {
		"source": SOURCE.IANA
	},
	"text/uri-list": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["uri","uris","urls"]
	},
	"text/vcard": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["vcard"]
	},
	"text/vnd.a": {
		"source": SOURCE.IANA
	},
	"text/vnd.abc": {
		"source": SOURCE.IANA
	},
	"text/vnd.ascii-art": {
		"source": SOURCE.IANA
	},
	"text/vnd.curl": {
		"source": SOURCE.IANA,
		"extensions": ["curl"]
	},
	"text/vnd.curl.dcurl": {
		"source": SOURCE.APACHE,
		"extensions": ["dcurl"]
	},
	"text/vnd.curl.mcurl": {
		"source": SOURCE.APACHE,
		"extensions": ["mcurl"]
	},
	"text/vnd.curl.scurl": {
		"source": SOURCE.APACHE,
		"extensions": ["scurl"]
	},
	"text/vnd.debian.copyright": {
		"source": SOURCE.IANA,
		"charset": UTF8
	},
	"text/vnd.dmclientscript": {
		"source": SOURCE.IANA
	},
	"text/vnd.dvb.subtitle": {
		"source": SOURCE.IANA,
		"extensions": ["sub"]
	},
	"text/vnd.esmertec.theme-descriptor": {
		"source": SOURCE.IANA,
		"charset": UTF8
	},
	"text/vnd.familysearch.gedcom": {
		"source": SOURCE.IANA,
		"extensions": ["ged"]
	},
	"text/vnd.ficlab.flt": {
		"source": SOURCE.IANA
	},
	"text/vnd.fly": {
		"source": SOURCE.IANA,
		"extensions": ["fly"]
	},
	"text/vnd.fmi.flexstor": {
		"source": SOURCE.IANA,
		"extensions": ["flx"]
	},
	"text/vnd.gml": {
		"source": SOURCE.IANA
	},
	"text/vnd.graphviz": {
		"source": SOURCE.IANA,
		"extensions": ["gv"]
	},
	"text/vnd.hans": {
		"source": SOURCE.IANA
	},
	"text/vnd.hgl": {
		"source": SOURCE.IANA
	},
	"text/vnd.in3d.3dml": {
		"source": SOURCE.IANA,
		"extensions": ["3dml"]
	},
	"text/vnd.in3d.spot": {
		"source": SOURCE.IANA,
		"extensions": ["spot"]
	},
	"text/vnd.iptc.newsml": {
		"source": SOURCE.IANA
	},
	"text/vnd.iptc.nitf": {
		"source": SOURCE.IANA
	},
	"text/vnd.latex-z": {
		"source": SOURCE.IANA
	},
	"text/vnd.motorola.reflex": {
		"source": SOURCE.IANA
	},
	"text/vnd.ms-mediapackage": {
		"source": SOURCE.IANA
	},
	"text/vnd.net2phone.commcenter.command": {
		"source": SOURCE.IANA
	},
	"text/vnd.radisys.msml-basic-layout": {
		"source": SOURCE.IANA
	},
	"text/vnd.senx.warpscript": {
		"source": SOURCE.IANA
	},
	"text/vnd.si.uricatalogue": {
		"source": SOURCE.APACHE
	},
	"text/vnd.sosi": {
		"source": SOURCE.IANA
	},
	"text/vnd.sun.j2me.app-descriptor": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"extensions": ["jad"]
	},
	"text/vnd.trolltech.linguist": {
		"source": SOURCE.IANA,
		"charset": UTF8
	},
	"text/vnd.wap.si": {
		"source": SOURCE.IANA
	},
	"text/vnd.wap.sl": {
		"source": SOURCE.IANA
	},
	"text/vnd.wap.wml": {
		"source": SOURCE.IANA,
		"extensions": ["wml"]
	},
	"text/vnd.wap.wmlscript": {
		"source": SOURCE.IANA,
		"extensions": ["wmls"]
	},
	"text/vtt": {
		"source": SOURCE.IANA,
		"charset": UTF8,
		"compressible": true,
		"extensions": ["vtt"]
	},
	"text/x-asm": {
		"source": SOURCE.APACHE,
		"extensions": ["s","asm"]
	},
	"text/x-c": {
		"source": SOURCE.APACHE,
		"extensions": ["c","cc","cxx","cpp","h","hh","dic"]
	},
	"text/x-component": {
		"source": SOURCE.NGINX,
		"extensions": ["htc"]
	},
	"text/x-fortran": {
		"source": SOURCE.APACHE,
		"extensions": ["f","for","f77","f90"]
	},
	"text/x-gwt-rpc": {
		"compressible": true
	},
	"text/x-handlebars-template": {
		"extensions": ["hbs"]
	},
	"text/x-java-source": {
		"source": SOURCE.APACHE,
		"extensions": ["java"]
	},
	"text/x-jquery-tmpl": {
		"compressible": true
	},
	"text/x-lua": {
		"extensions": ["lua"]
	},
	"text/x-markdown": {
		"compressible": true,
		"extensions": ["mkd"]
	},
	"text/x-nfo": {
		"source": SOURCE.APACHE,
		"extensions": ["nfo"]
	},
	"text/x-opml": {
		"source": SOURCE.APACHE,
		"extensions": ["opml"]
	},
	"text/x-org": {
		"compressible": true,
		"extensions": ["org"]
	},
	"text/x-pascal": {
		"source": SOURCE.APACHE,
		"extensions": ["p","pas"]
	},
	"text/x-processing": {
		"compressible": true,
		"extensions": ["pde"]
	},
	"text/x-sass": {
		"extensions": ["sass"]
	},
	"text/x-scss": {
		"extensions": ["scss"]
	},
	"text/x-setext": {
		"source": SOURCE.APACHE,
		"extensions": ["etx"]
	},
	"text/x-sfv": {
		"source": SOURCE.APACHE,
		"extensions": ["sfv"]
	},
	"text/x-suse-ymp": {
		"compressible": true,
		"extensions": ["ymp"]
	},
	"text/x-uuencode": {
		"source": SOURCE.APACHE,
		"extensions": ["uu"]
	},
	"text/x-vcalendar": {
		"source": SOURCE.APACHE,
		"extensions": ["vcs"]
	},
	"text/x-vcard": {
		"source": SOURCE.APACHE,
		"extensions": ["vcf"]
	},
	"text/xml": {
		"source": SOURCE.IANA,
		"compressible": true,
		"extensions": ["xml"]
	},
	"text/xml-external-parsed-entity": {
		"source": SOURCE.IANA
	},
	"text/yaml": {
		"compressible": true,
		"extensions": ["yaml","yml"]
	},
	"video/1d-interleaved-parityfec": {
		"source": SOURCE.IANA
	},
	"video/3gpp": {
		"source": SOURCE.IANA,
		"extensions": ["3gp","3gpp"]
	},
	"video/3gpp-tt": {
		"source": SOURCE.IANA
	},
	"video/3gpp2": {
		"source": SOURCE.IANA,
		"extensions": ["3g2"]
	},
	"video/av1": {
		"source": SOURCE.IANA
	},
	"video/bmpeg": {
		"source": SOURCE.IANA
	},
	"video/bt656": {
		"source": SOURCE.IANA
	},
	"video/celb": {
		"source": SOURCE.IANA
	},
	"video/dv": {
		"source": SOURCE.IANA
	},
	"video/encaprtp": {
		"source": SOURCE.IANA
	},
	"video/ffv1": {
		"source": SOURCE.IANA
	},
	"video/flexfec": {
		"source": SOURCE.IANA
	},
	"video/h261": {
		"source": SOURCE.IANA,
		"extensions": ["h261"]
	},
	"video/h263": {
		"source": SOURCE.IANA,
		"extensions": ["h263"]
	},
	"video/h263-1998": {
		"source": SOURCE.IANA
	},
	"video/h263-2000": {
		"source": SOURCE.IANA
	},
	"video/h264": {
		"source": SOURCE.IANA,
		"extensions": ["h264"]
	},
	"video/h264-rcdo": {
		"source": SOURCE.IANA
	},
	"video/h264-svc": {
		"source": SOURCE.IANA
	},
	"video/h265": {
		"source": SOURCE.IANA
	},
	"video/iso.segment": {
		"source": SOURCE.IANA,
		"extensions": ["m4s"]
	},
	"video/jpeg": {
		"source": SOURCE.IANA,
		"extensions": ["jpgv"]
	},
	"video/jpeg2000": {
		"source": SOURCE.IANA
	},
	"video/jpm": {
		"source": SOURCE.APACHE,
		"extensions": ["jpm","jpgm"]
	},
	"video/jxsv": {
		"source": SOURCE.IANA
	},
	"video/mj2": {
		"source": SOURCE.IANA,
		"extensions": ["mj2","mjp2"]
	},
	"video/mp1s": {
		"source": SOURCE.IANA
	},
	"video/mp2p": {
		"source": SOURCE.IANA
	},
	"video/mp2t": {
		"source": SOURCE.IANA,
		"extensions": ["ts"]
	},
	"video/mp4": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["mp4","mp4v","mpg4"]
	},
	"video/mp4v-es": {
		"source": SOURCE.IANA
	},
	"video/mpeg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["mpeg","mpg","mpe","m1v","m2v"]
	},
	"video/mpeg4-generic": {
		"source": SOURCE.IANA
	},
	"video/mpv": {
		"source": SOURCE.IANA
	},
	"video/nv": {
		"source": SOURCE.IANA
	},
	"video/ogg": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["ogv"]
	},
	"video/parityfec": {
		"source": SOURCE.IANA
	},
	"video/pointer": {
		"source": SOURCE.IANA
	},
	"video/quicktime": {
		"source": SOURCE.IANA,
		"compressible": false,
		"extensions": ["qt","mov"]
	},
	"video/raptorfec": {
		"source": SOURCE.IANA
	},
	"video/raw": {
		"source": SOURCE.IANA
	},
	"video/rtp-enc-aescm128": {
		"source": SOURCE.IANA
	},
	"video/rtploopback": {
		"source": SOURCE.IANA
	},
	"video/rtx": {
		"source": SOURCE.IANA
	},
	"video/scip": {
		"source": SOURCE.IANA
	},
	"video/smpte291": {
		"source": SOURCE.IANA
	},
	"video/smpte292m": {
		"source": SOURCE.IANA
	},
	"video/ulpfec": {
		"source": SOURCE.IANA
	},
	"video/vc1": {
		"source": SOURCE.IANA
	},
	"video/vc2": {
		"source": SOURCE.IANA
	},
	"video/vnd.cctv": {
		"source": SOURCE.IANA
	},
	"video/vnd.dece.hd": {
		"source": SOURCE.IANA,
		"extensions": ["uvh","uvvh"]
	},
	"video/vnd.dece.mobile": {
		"source": SOURCE.IANA,
		"extensions": ["uvm","uvvm"]
	},
	"video/vnd.dece.mp4": {
		"source": SOURCE.IANA
	},
	"video/vnd.dece.pd": {
		"source": SOURCE.IANA,
		"extensions": ["uvp","uvvp"]
	},
	"video/vnd.dece.sd": {
		"source": SOURCE.IANA,
		"extensions": ["uvs","uvvs"]
	},
	"video/vnd.dece.video": {
		"source": SOURCE.IANA,
		"extensions": ["uvv","uvvv"]
	},
	"video/vnd.directv.mpeg": {
		"source": SOURCE.IANA
	},
	"video/vnd.directv.mpeg-tts": {
		"source": SOURCE.IANA
	},
	"video/vnd.dlna.mpeg-tts": {
		"source": SOURCE.IANA
	},
	"video/vnd.dvb.file": {
		"source": SOURCE.IANA,
		"extensions": ["dvb"]
	},
	"video/vnd.fvt": {
		"source": SOURCE.IANA,
		"extensions": ["fvt"]
	},
	"video/vnd.hns.video": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.1dparityfec-1010": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.1dparityfec-2005": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.2dparityfec-1010": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.2dparityfec-2005": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.ttsavc": {
		"source": SOURCE.IANA
	},
	"video/vnd.iptvforum.ttsmpeg2": {
		"source": SOURCE.IANA
	},
	"video/vnd.motorola.video": {
		"source": SOURCE.IANA
	},
	"video/vnd.motorola.videop": {
		"source": SOURCE.IANA
	},
	"video/vnd.mpegurl": {
		"source": SOURCE.IANA,
		"extensions": ["mxu","m4u"]
	},
	"video/vnd.ms-playready.media.pyv": {
		"source": SOURCE.IANA,
		"extensions": ["pyv"]
	},
	"video/vnd.nokia.interleaved-multimedia": {
		"source": SOURCE.IANA
	},
	"video/vnd.nokia.mp4vr": {
		"source": SOURCE.IANA
	},
	"video/vnd.nokia.videovoip": {
		"source": SOURCE.IANA
	},
	"video/vnd.objectvideo": {
		"source": SOURCE.IANA
	},
	"video/vnd.radgamettools.bink": {
		"source": SOURCE.IANA
	},
	"video/vnd.radgamettools.smacker": {
		"source": SOURCE.APACHE
	},
	"video/vnd.sealed.mpeg1": {
		"source": SOURCE.IANA
	},
	"video/vnd.sealed.mpeg4": {
		"source": SOURCE.IANA
	},
	"video/vnd.sealed.swf": {
		"source": SOURCE.IANA
	},
	"video/vnd.sealedmedia.softseal.mov": {
		"source": SOURCE.IANA
	},
	"video/vnd.uvvu.mp4": {
		"source": SOURCE.IANA,
		"extensions": ["uvu","uvvu"]
	},
	"video/vnd.vivo": {
		"source": SOURCE.IANA,
		"extensions": ["viv"]
	},
	"video/vnd.youtube.yt": {
		"source": SOURCE.IANA
	},
	"video/vp8": {
		"source": SOURCE.IANA
	},
	"video/vp9": {
		"source": SOURCE.IANA
	},
	"video/webm": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["webm"]
	},
	"video/x-f4v": {
		"source": SOURCE.APACHE,
		"extensions": ["f4v"]
	},
	"video/x-fli": {
		"source": SOURCE.APACHE,
		"extensions": ["fli"]
	},
	"video/x-flv": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["flv"]
	},
	"video/x-m4v": {
		"source": SOURCE.APACHE,
		"extensions": ["m4v"]
	},
	"video/x-matroska": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["mkv","mk3d","mks"]
	},
	"video/x-mng": {
		"source": SOURCE.APACHE,
		"extensions": ["mng"]
	},
	"video/x-ms-asf": {
		"source": SOURCE.APACHE,
		"extensions": ["asf","asx"]
	},
	"video/x-ms-vob": {
		"source": SOURCE.APACHE,
		"extensions": ["vob"]
	},
	"video/x-ms-wm": {
		"source": SOURCE.APACHE,
		"extensions": ["wm"]
	},
	"video/x-ms-wmv": {
		"source": SOURCE.APACHE,
		"compressible": false,
		"extensions": ["wmv"]
	},
	"video/x-ms-wmx": {
		"source": SOURCE.APACHE,
		"extensions": ["wmx"]
	},
	"video/x-ms-wvx": {
		"source": SOURCE.APACHE,
		"extensions": ["wvx"]
	},
	"video/x-msvideo": {
		"source": SOURCE.APACHE,
		"extensions": ["avi"]
	},
	"video/x-sgi-movie": {
		"source": SOURCE.APACHE,
		"extensions": ["movie"]
	},
	"video/x-smv": {
		"source": SOURCE.APACHE,
		"extensions": ["smv"]
	},
	"x-conference/x-cooltalk": {
		"source": SOURCE.APACHE,
		"extensions": ["ice"]
	},
	"x-shader/x-fragment": {
		"compressible": true
	},
	"x-shader/x-vertex": {
		"compressible": true
	}
}
